var Module = typeof libopenmpt != "undefined" ? libopenmpt : {};

var ENVIRONMENT_IS_WEB = typeof window == "object";

var ENVIRONMENT_IS_WORKER = typeof importScripts == "function";

var ENVIRONMENT_IS_NODE = typeof process == "object" && typeof process.versions == "object" && typeof process.versions.node == "string";

if (ENVIRONMENT_IS_NODE) {}

var moduleOverrides = Object.assign({}, Module);

var arguments_ = [];

var thisProgram = "./this.program";

var quit_ = (status, toThrow) => {
  throw toThrow;
};

var scriptDirectory = "";

function locateFile(path) {
  if (Module["locateFile"]) {
    return Module["locateFile"](path, scriptDirectory);
  }
  return scriptDirectory + path;
}

var read_, readAsync, readBinary;

if (ENVIRONMENT_IS_NODE) {
  var fs = require("fs");
  var nodePath = require("path");
  scriptDirectory = __dirname + "/";
  read_ = (filename, binary) => {
    filename = isFileURI(filename) ? new URL(filename) : nodePath.normalize(filename);
    return fs.readFileSync(filename, binary ? undefined : "utf8");
  };
  readBinary = filename => {
    var ret = read_(filename, true);
    if (!ret.buffer) {
      ret = new Uint8Array(ret);
    }
    return ret;
  };
  readAsync = (filename, onload, onerror, binary = true) => {
    filename = isFileURI(filename) ? new URL(filename) : nodePath.normalize(filename);
    fs.readFile(filename, binary ? undefined : "utf8", (err, data) => {
      if (err) onerror(err); else onload(binary ? data.buffer : data);
    });
  };
  if (!Module["thisProgram"] && process.argv.length > 1) {
    thisProgram = process.argv[1].replace(/\\/g, "/");
  }
  arguments_ = process.argv.slice(2);
  if (typeof module != "undefined") {
    module["exports"] = Module;
  }
  process.on("uncaughtException", ex => {
    if (ex !== "unwind" && !(ex instanceof ExitStatus) && !(ex.context instanceof ExitStatus)) {
      throw ex;
    }
  });
  quit_ = (status, toThrow) => {
    process.exitCode = status;
    throw toThrow;
  };
} else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  if (ENVIRONMENT_IS_WORKER) {
    scriptDirectory = self.location.href;
  } else if (typeof document != "undefined" && document.currentScript) {
    scriptDirectory = document.currentScript.src;
  }
  if (scriptDirectory.startsWith("blob:")) {
    scriptDirectory = "";
  } else {
    scriptDirectory = scriptDirectory.substr(0, scriptDirectory.replace(/[?#].*/, "").lastIndexOf("/") + 1);
  }
  {
    read_ = url => {
      var xhr = new XMLHttpRequest;
      xhr.open("GET", url, false);
      xhr.send(null);
      return xhr.responseText;
    };
    if (ENVIRONMENT_IS_WORKER) {
      readBinary = url => {
        var xhr = new XMLHttpRequest;
        xhr.open("GET", url, false);
        xhr.responseType = "arraybuffer";
        xhr.send(null);
        return new Uint8Array(/** @type{!ArrayBuffer} */ (xhr.response));
      };
    }
    readAsync = (url, onload, onerror) => {
      if (isFileURI(url)) {
        var xhr = new XMLHttpRequest;
        xhr.open("GET", url, true);
        xhr.responseType = "arraybuffer";
        xhr.onload = () => {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) {
            onload(xhr.response);
            return;
          }
          onerror();
        };
        xhr.onerror = onerror;
        xhr.send(null);
        return;
      }
      fetch(url, {
        credentials: "same-origin"
      }).then(response => {
        if (response.ok) {
          return response.arrayBuffer();
        }
        return Promise.reject(new Error(response.status + " : " + response.url));
      }).then(onload, onerror);
    };
  }
} else {}

var out = Module["print"] || console.log.bind(console);

var err = Module["printErr"] || console.error.bind(console);

Object.assign(Module, moduleOverrides);

moduleOverrides = null;

if (Module["arguments"]) arguments_ = Module["arguments"];

if (Module["thisProgram"]) thisProgram = Module["thisProgram"];

if (Module["quit"]) quit_ = Module["quit"];

var wasmBinary;

if (Module["wasmBinary"]) wasmBinary = Module["wasmBinary"];

var wasmMemory;

var ABORT = false;

var EXITSTATUS;

var /** @type {!Int8Array} */ HEAP8, /** @type {!Uint8Array} */ HEAPU8, /** @type {!Int16Array} */ HEAP16, /** @type {!Uint16Array} */ HEAPU16, /** @type {!Int32Array} */ HEAP32, /** @type {!Uint32Array} */ HEAPU32, /** @type {!Float32Array} */ HEAPF32, /** @type {!Float64Array} */ HEAPF64;

function updateMemoryViews() {
  var b = wasmMemory.buffer;
  Module["HEAP8"] = HEAP8 = new Int8Array(b);
  Module["HEAP16"] = HEAP16 = new Int16Array(b);
  Module["HEAPU8"] = HEAPU8 = new Uint8Array(b);
  Module["HEAPU16"] = HEAPU16 = new Uint16Array(b);
  Module["HEAP32"] = HEAP32 = new Int32Array(b);
  Module["HEAPU32"] = HEAPU32 = new Uint32Array(b);
  Module["HEAPF32"] = HEAPF32 = new Float32Array(b);
  Module["HEAPF64"] = HEAPF64 = new Float64Array(b);
}

var __ATPRERUN__ = [];

var __ATINIT__ = [];

var __ATPOSTRUN__ = [];

var runtimeInitialized = false;

function preRun() {
  if (Module["preRun"]) {
    if (typeof Module["preRun"] == "function") Module["preRun"] = [ Module["preRun"] ];
    while (Module["preRun"].length) {
      addOnPreRun(Module["preRun"].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function initRuntime() {
  runtimeInitialized = true;
  if (!Module["noFSInit"] && !FS.init.initialized) FS.init();
  FS.ignorePermissions = false;
  TTY.init();
  callRuntimeCallbacks(__ATINIT__);
}

function postRun() {
  if (Module["postRun"]) {
    if (typeof Module["postRun"] == "function") Module["postRun"] = [ Module["postRun"] ];
    while (Module["postRun"].length) {
      addOnPostRun(Module["postRun"].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}

var runDependencies = 0;

var runDependencyWatcher = null;

var dependenciesFulfilled = null;

function getUniqueRunDependency(id) {
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  Module["monitorRunDependencies"]?.(runDependencies);
}

function removeRunDependency(id) {
  runDependencies--;
  Module["monitorRunDependencies"]?.(runDependencies);
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback();
    }
  }
}

/** @param {string|number=} what */ function abort(what) {
  Module["onAbort"]?.(what);
  what = "Aborted(" + what + ")";
  err(what);
  ABORT = true;
  EXITSTATUS = 1;
  what += ". Build with -sASSERTIONS for more info.";
  /** @suppress {checkTypes} */ var e = new WebAssembly.RuntimeError(what);
  throw e;
}

var dataURIPrefix = "data:application/octet-stream;base64,";

/**
 * Indicates whether filename is a base64 data URI.
 * @noinline
 */ var isDataURI = filename => filename.startsWith(dataURIPrefix);

/**
 * Indicates whether filename is delivered via file protocol (as opposed to http/https)
 * @noinline
 */ var isFileURI = filename => filename.startsWith("file://");

function findWasmBinary() {
  var f = "libopenmpt.wasm";
  if (!isDataURI(f)) {
    return locateFile(f);
  }
  return f;
}

var wasmBinaryFile;

function getBinarySync(file) {
  if (file == wasmBinaryFile && wasmBinary) {
    return new Uint8Array(wasmBinary);
  }
  if (readBinary) {
    return readBinary(file);
  }
  throw "both async and sync fetching of the wasm failed";
}

function getBinaryPromise(binaryFile) {
  if (!wasmBinary) {
    return new Promise((resolve, reject) => {
      readAsync(binaryFile, response => resolve(new Uint8Array(/** @type{!ArrayBuffer} */ (response))), error => {
        try {
          resolve(getBinarySync(binaryFile));
        } catch (e) {
          reject(e);
        }
      });
    });
  }
  return Promise.resolve().then(() => getBinarySync(binaryFile));
}

function instantiateArrayBuffer(binaryFile, imports, receiver) {
  return getBinaryPromise(binaryFile).then(binary => WebAssembly.instantiate(binary, imports)).then(receiver, reason => {
    err(`failed to asynchronously prepare wasm: ${reason}`);
    abort(reason);
  });
}

function instantiateAsync(binary, binaryFile, imports, callback) {
  if (!binary && typeof WebAssembly.instantiateStreaming == "function" && !isDataURI(binaryFile) && !isFileURI(binaryFile) && !ENVIRONMENT_IS_NODE && typeof fetch == "function") {
    return fetch(binaryFile, {
      credentials: "same-origin"
    }).then(response => {
      /** @suppress {checkTypes} */ var result = WebAssembly.instantiateStreaming(response, imports);
      return result.then(callback, function(reason) {
        err(`wasm streaming compile failed: ${reason}`);
        err("falling back to ArrayBuffer instantiation");
        return instantiateArrayBuffer(binaryFile, imports, callback);
      });
    });
  }
  return instantiateArrayBuffer(binaryFile, imports, callback);
}

function getWasmImports() {
  return {
    "a": wasmImports
  };
}

function createWasm() {
  var info = getWasmImports();
  /** @param {WebAssembly.Module=} module*/ function receiveInstance(instance, module) {
    wasmExports = instance.exports;
    wasmMemory = wasmExports["va"];
    updateMemoryViews();
    wasmTable = wasmExports["_e"];
    addOnInit(wasmExports["wa"]);
    removeRunDependency("wasm-instantiate");
    return wasmExports;
  }
  addRunDependency("wasm-instantiate");
  function receiveInstantiationResult(result) {
    receiveInstance(result["instance"]);
  }
  if (Module["instantiateWasm"]) {
    try {
      return Module["instantiateWasm"](info, receiveInstance);
    } catch (e) {
      err(`Module.instantiateWasm callback failed with error: ${e}`);
      return false;
    }
  }
  if (!wasmBinaryFile) wasmBinaryFile = findWasmBinary();
  instantiateAsync(wasmBinary, wasmBinaryFile, info, receiveInstantiationResult);
  return {};
}

var tempDouble;

var tempI64;

/** @constructor */ function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = `Program terminated with exit(${status})`;
  this.status = status;
}

var callRuntimeCallbacks = callbacks => {
  while (callbacks.length > 0) {
    callbacks.shift()(Module);
  }
};

var noExitRuntime = Module["noExitRuntime"] || true;

var stackRestore = val => __emscripten_stack_restore(val);

var stackSave = () => _emscripten_stack_get_current();

var UTF8Decoder = typeof TextDecoder != "undefined" ? new TextDecoder("utf8") : undefined;

/**
     * Given a pointer 'idx' to a null-terminated UTF8-encoded string in the given
     * array that contains uint8 values, returns a copy of that string as a
     * Javascript String object.
     * heapOrArray is either a regular array, or a JavaScript typed array view.
     * @param {number} idx
     * @param {number=} maxBytesToRead
     * @return {string}
     */ var UTF8ArrayToString = (heapOrArray, idx, maxBytesToRead) => {
  var endIdx = idx + maxBytesToRead;
  var endPtr = idx;
  while (heapOrArray[endPtr] && !(endPtr >= endIdx)) ++endPtr;
  if (endPtr - idx > 16 && heapOrArray.buffer && UTF8Decoder) {
    return UTF8Decoder.decode(heapOrArray.subarray(idx, endPtr));
  }
  var str = "";
  while (idx < endPtr) {
    var u0 = heapOrArray[idx++];
    if (!(u0 & 128)) {
      str += String.fromCharCode(u0);
      continue;
    }
    var u1 = heapOrArray[idx++] & 63;
    if ((u0 & 224) == 192) {
      str += String.fromCharCode(((u0 & 31) << 6) | u1);
      continue;
    }
    var u2 = heapOrArray[idx++] & 63;
    if ((u0 & 240) == 224) {
      u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
    } else {
      u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | (heapOrArray[idx++] & 63);
    }
    if (u0 < 65536) {
      str += String.fromCharCode(u0);
    } else {
      var ch = u0 - 65536;
      str += String.fromCharCode(55296 | (ch >> 10), 56320 | (ch & 1023));
    }
  }
  return str;
};

/**
     * Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the
     * emscripten HEAP, returns a copy of that string as a Javascript String object.
     *
     * @param {number} ptr
     * @param {number=} maxBytesToRead - An optional length that specifies the
     *   maximum number of bytes to read. You can omit this parameter to scan the
     *   string until the first 0 byte. If maxBytesToRead is passed, and the string
     *   at [ptr, ptr+maxBytesToReadr[ contains a null byte in the middle, then the
     *   string will cut short at that byte index (i.e. maxBytesToRead will not
     *   produce a string of exact length [ptr, ptr+maxBytesToRead[) N.B. mixing
     *   frequent uses of UTF8ToString() with and without maxBytesToRead may throw
     *   JS JIT optimizations off, so it is worth to consider consistently using one
     * @return {string}
     */ var UTF8ToString = (ptr, maxBytesToRead) => ptr ? UTF8ArrayToString(HEAPU8, ptr, maxBytesToRead) : "";

var ___assert_fail = (condition, filename, line, func) => {
  abort(`Assertion failed: ${UTF8ToString(condition)}, at: ` + [ filename ? UTF8ToString(filename) : "unknown filename", line, func ? UTF8ToString(func) : "unknown function" ]);
};

var exceptionCaught = [];

var uncaughtExceptionCount = 0;

var ___cxa_begin_catch = ptr => {
  var info = new ExceptionInfo(ptr);
  if (!info.get_caught()) {
    info.set_caught(true);
    uncaughtExceptionCount--;
  }
  info.set_rethrown(false);
  exceptionCaught.push(info);
  ___cxa_increment_exception_refcount(info.excPtr);
  return info.get_exception_ptr();
};

var exceptionLast = 0;

var ___cxa_end_catch = () => {
  _setThrew(0, 0);
  var info = exceptionCaught.pop();
  ___cxa_decrement_exception_refcount(info.excPtr);
  exceptionLast = 0;
};

class ExceptionInfo {
  constructor(excPtr) {
    this.excPtr = excPtr;
    this.ptr = excPtr - 24;
  }
  set_type(type) {
    HEAPU32[(((this.ptr) + (4)) >> 2)] = type;
  }
  get_type() {
    return HEAPU32[(((this.ptr) + (4)) >> 2)];
  }
  set_destructor(destructor) {
    HEAPU32[(((this.ptr) + (8)) >> 2)] = destructor;
  }
  get_destructor() {
    return HEAPU32[(((this.ptr) + (8)) >> 2)];
  }
  set_caught(caught) {
    caught = caught ? 1 : 0;
    HEAP8[(this.ptr) + (12)] = caught;
  }
  get_caught() {
    return HEAP8[(this.ptr) + (12)] != 0;
  }
  set_rethrown(rethrown) {
    rethrown = rethrown ? 1 : 0;
    HEAP8[(this.ptr) + (13)] = rethrown;
  }
  get_rethrown() {
    return HEAP8[(this.ptr) + (13)] != 0;
  }
  init(type, destructor) {
    this.set_adjusted_ptr(0);
    this.set_type(type);
    this.set_destructor(destructor);
  }
  set_adjusted_ptr(adjustedPtr) {
    HEAPU32[(((this.ptr) + (16)) >> 2)] = adjustedPtr;
  }
  get_adjusted_ptr() {
    return HEAPU32[(((this.ptr) + (16)) >> 2)];
  }
  get_exception_ptr() {
    var isPointer = ___cxa_is_pointer_type(this.get_type());
    if (isPointer) {
      return HEAPU32[((this.excPtr) >> 2)];
    }
    var adjusted = this.get_adjusted_ptr();
    if (adjusted !== 0) return adjusted;
    return this.excPtr;
  }
}

var ___resumeException = ptr => {
  if (!exceptionLast) {
    exceptionLast = ptr;
  }
  throw exceptionLast;
};

var setTempRet0 = val => __emscripten_tempret_set(val);

var findMatchingCatch = args => {
  var thrown = exceptionLast;
  if (!thrown) {
    setTempRet0(0);
    return 0;
  }
  var info = new ExceptionInfo(thrown);
  info.set_adjusted_ptr(thrown);
  var thrownType = info.get_type();
  if (!thrownType) {
    setTempRet0(0);
    return thrown;
  }
  for (var caughtType of args) {
    if (caughtType === 0 || caughtType === thrownType) {
      break;
    }
    var adjusted_ptr_addr = info.ptr + 16;
    if (___cxa_can_catch(caughtType, thrownType, adjusted_ptr_addr)) {
      setTempRet0(caughtType);
      return thrown;
    }
  }
  setTempRet0(thrownType);
  return thrown;
};

var ___cxa_find_matching_catch_17 = (arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11, arg12, arg13, arg14) => findMatchingCatch([ arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11, arg12, arg13, arg14 ]);

var ___cxa_find_matching_catch_2 = () => findMatchingCatch([]);

var ___cxa_find_matching_catch_3 = arg0 => findMatchingCatch([ arg0 ]);

var ___cxa_find_matching_catch_4 = (arg0, arg1) => findMatchingCatch([ arg0, arg1 ]);

var ___cxa_find_matching_catch_6 = (arg0, arg1, arg2, arg3) => findMatchingCatch([ arg0, arg1, arg2, arg3 ]);

var ___cxa_rethrow = () => {
  var info = exceptionCaught.pop();
  if (!info) {
    abort("no exception to throw");
  }
  var ptr = info.excPtr;
  if (!info.get_rethrown()) {
    exceptionCaught.push(info);
    info.set_rethrown(true);
    info.set_caught(false);
    uncaughtExceptionCount++;
  }
  exceptionLast = ptr;
  throw exceptionLast;
};

var ___cxa_throw = (ptr, type, destructor) => {
  var info = new ExceptionInfo(ptr);
  info.init(type, destructor);
  exceptionLast = ptr;
  uncaughtExceptionCount++;
  throw exceptionLast;
};

var ___cxa_uncaught_exceptions = () => uncaughtExceptionCount;

var __abort_js = () => {
  abort("");
};

var nowIsMonotonic = 1;

var __emscripten_get_now_is_monotonic = () => nowIsMonotonic;

var _emscripten_date_now = () => Date.now();

var _emscripten_get_now;

_emscripten_get_now = () => performance.now();

var getHeapMax = () => 2147483648;

var growMemory = size => {
  var b = wasmMemory.buffer;
  var pages = (size - b.byteLength + 65535) / 65536;
  try {
    wasmMemory.grow(pages);
    updateMemoryViews();
    return 1;
  } /*success*/ catch (e) {}
};

var _emscripten_resize_heap = requestedSize => {
  var oldSize = HEAPU8.length;
  requestedSize >>>= 0;
  var maxHeapSize = getHeapMax();
  if (requestedSize > maxHeapSize) {
    return false;
  }
  var alignUp = (x, multiple) => x + (multiple - x % multiple) % multiple;
  for (var cutDown = 1; cutDown <= 4; cutDown *= 2) {
    var overGrownHeapSize = oldSize * (1 + .2 / cutDown);
    overGrownHeapSize = Math.min(overGrownHeapSize, requestedSize + 100663296);
    var newSize = Math.min(maxHeapSize, alignUp(Math.max(requestedSize, overGrownHeapSize), 65536));
    var replacement = growMemory(newSize);
    if (replacement) {
      return true;
    }
  }
  return false;
};

var ENV = {};

var getExecutableName = () => thisProgram || "./this.program";

var getEnvStrings = () => {
  if (!getEnvStrings.strings) {
    var lang = ((typeof navigator == "object" && navigator.languages && navigator.languages[0]) || "C").replace("-", "_") + ".UTF-8";
    var env = {
      "USER": "web_user",
      "LOGNAME": "web_user",
      "PATH": "/",
      "PWD": "/",
      "HOME": "/home/web_user",
      "LANG": lang,
      "_": getExecutableName()
    };
    for (var x in ENV) {
      if (ENV[x] === undefined) delete env[x]; else env[x] = ENV[x];
    }
    var strings = [];
    for (var x in env) {
      strings.push(`${x}=${env[x]}`);
    }
    getEnvStrings.strings = strings;
  }
  return getEnvStrings.strings;
};

var stringToAscii = (str, buffer) => {
  for (var i = 0; i < str.length; ++i) {
    HEAP8[buffer++] = str.charCodeAt(i);
  }
  HEAP8[buffer] = 0;
};

var _environ_get = (__environ, environ_buf) => {
  var bufSize = 0;
  getEnvStrings().forEach((string, i) => {
    var ptr = environ_buf + bufSize;
    HEAPU32[(((__environ) + (i * 4)) >> 2)] = ptr;
    stringToAscii(string, ptr);
    bufSize += string.length + 1;
  });
  return 0;
};

var _environ_sizes_get = (penviron_count, penviron_buf_size) => {
  var strings = getEnvStrings();
  HEAPU32[((penviron_count) >> 2)] = strings.length;
  var bufSize = 0;
  strings.forEach(string => bufSize += string.length + 1);
  HEAPU32[((penviron_buf_size) >> 2)] = bufSize;
  return 0;
};

var PATH = {
  isAbs: path => path.charAt(0) === "/",
  splitPath: filename => {
    var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
    return splitPathRe.exec(filename).slice(1);
  },
  normalizeArray: (parts, allowAboveRoot) => {
    var up = 0;
    for (var i = parts.length - 1; i >= 0; i--) {
      var last = parts[i];
      if (last === ".") {
        parts.splice(i, 1);
      } else if (last === "..") {
        parts.splice(i, 1);
        up++;
      } else if (up) {
        parts.splice(i, 1);
        up--;
      }
    }
    if (allowAboveRoot) {
      for (;up; up--) {
        parts.unshift("..");
      }
    }
    return parts;
  },
  normalize: path => {
    var isAbsolute = PATH.isAbs(path), trailingSlash = path.substr(-1) === "/";
    path = PATH.normalizeArray(path.split("/").filter(p => !!p), !isAbsolute).join("/");
    if (!path && !isAbsolute) {
      path = ".";
    }
    if (path && trailingSlash) {
      path += "/";
    }
    return (isAbsolute ? "/" : "") + path;
  },
  dirname: path => {
    var result = PATH.splitPath(path), root = result[0], dir = result[1];
    if (!root && !dir) {
      return ".";
    }
    if (dir) {
      dir = dir.substr(0, dir.length - 1);
    }
    return root + dir;
  },
  basename: path => {
    if (path === "/") return "/";
    path = PATH.normalize(path);
    path = path.replace(/\/$/, "");
    var lastSlash = path.lastIndexOf("/");
    if (lastSlash === -1) return path;
    return path.substr(lastSlash + 1);
  },
  join: (...paths) => PATH.normalize(paths.join("/")),
  join2: (l, r) => PATH.normalize(l + "/" + r)
};

var initRandomFill = () => {
  if (typeof crypto == "object" && typeof crypto["getRandomValues"] == "function") {
    return view => crypto.getRandomValues(view);
  } else if (ENVIRONMENT_IS_NODE) {
    try {
      var crypto_module = require("crypto");
      var randomFillSync = crypto_module["randomFillSync"];
      if (randomFillSync) {
        return view => crypto_module["randomFillSync"](view);
      }
      var randomBytes = crypto_module["randomBytes"];
      return view => (view.set(randomBytes(view.byteLength)), view);
    } catch (e) {}
  }
  abort("initRandomDevice");
};

var randomFill = view => (randomFill = initRandomFill())(view);

var PATH_FS = {
  resolve: (...args) => {
    var resolvedPath = "", resolvedAbsolute = false;
    for (var i = args.length - 1; i >= -1 && !resolvedAbsolute; i--) {
      var path = (i >= 0) ? args[i] : FS.cwd();
      if (typeof path != "string") {
        throw new TypeError("Arguments to path.resolve must be strings");
      } else if (!path) {
        return "";
      }
      resolvedPath = path + "/" + resolvedPath;
      resolvedAbsolute = PATH.isAbs(path);
    }
    resolvedPath = PATH.normalizeArray(resolvedPath.split("/").filter(p => !!p), !resolvedAbsolute).join("/");
    return ((resolvedAbsolute ? "/" : "") + resolvedPath) || ".";
  },
  relative: (from, to) => {
    from = PATH_FS.resolve(from).substr(1);
    to = PATH_FS.resolve(to).substr(1);
    function trim(arr) {
      var start = 0;
      for (;start < arr.length; start++) {
        if (arr[start] !== "") break;
      }
      var end = arr.length - 1;
      for (;end >= 0; end--) {
        if (arr[end] !== "") break;
      }
      if (start > end) return [];
      return arr.slice(start, end - start + 1);
    }
    var fromParts = trim(from.split("/"));
    var toParts = trim(to.split("/"));
    var length = Math.min(fromParts.length, toParts.length);
    var samePartsLength = length;
    for (var i = 0; i < length; i++) {
      if (fromParts[i] !== toParts[i]) {
        samePartsLength = i;
        break;
      }
    }
    var outputParts = [];
    for (var i = samePartsLength; i < fromParts.length; i++) {
      outputParts.push("..");
    }
    outputParts = outputParts.concat(toParts.slice(samePartsLength));
    return outputParts.join("/");
  }
};

var FS_stdin_getChar_buffer = [];

var lengthBytesUTF8 = str => {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    var c = str.charCodeAt(i);
    if (c <= 127) {
      len++;
    } else if (c <= 2047) {
      len += 2;
    } else if (c >= 55296 && c <= 57343) {
      len += 4;
      ++i;
    } else {
      len += 3;
    }
  }
  return len;
};

var stringToUTF8Array = (str, heap, outIdx, maxBytesToWrite) => {
  if (!(maxBytesToWrite > 0)) return 0;
  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1;
  for (var i = 0; i < str.length; ++i) {
    var u = str.charCodeAt(i);
    if (u >= 55296 && u <= 57343) {
      var u1 = str.charCodeAt(++i);
      u = 65536 + ((u & 1023) << 10) | (u1 & 1023);
    }
    if (u <= 127) {
      if (outIdx >= endIdx) break;
      heap[outIdx++] = u;
    } else if (u <= 2047) {
      if (outIdx + 1 >= endIdx) break;
      heap[outIdx++] = 192 | (u >> 6);
      heap[outIdx++] = 128 | (u & 63);
    } else if (u <= 65535) {
      if (outIdx + 2 >= endIdx) break;
      heap[outIdx++] = 224 | (u >> 12);
      heap[outIdx++] = 128 | ((u >> 6) & 63);
      heap[outIdx++] = 128 | (u & 63);
    } else {
      if (outIdx + 3 >= endIdx) break;
      heap[outIdx++] = 240 | (u >> 18);
      heap[outIdx++] = 128 | ((u >> 12) & 63);
      heap[outIdx++] = 128 | ((u >> 6) & 63);
      heap[outIdx++] = 128 | (u & 63);
    }
  }
  heap[outIdx] = 0;
  return outIdx - startIdx;
};

/** @type {function(string, boolean=, number=)} */ function intArrayFromString(stringy, dontAddNull, length) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy) + 1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}

var FS_stdin_getChar = () => {
  if (!FS_stdin_getChar_buffer.length) {
    var result = null;
    if (ENVIRONMENT_IS_NODE) {
      var BUFSIZE = 256;
      var buf = Buffer.alloc(BUFSIZE);
      var bytesRead = 0;
      /** @suppress {missingProperties} */ var fd = process.stdin.fd;
      try {
        bytesRead = fs.readSync(fd, buf, 0, BUFSIZE);
      } catch (e) {
        if (e.toString().includes("EOF")) bytesRead = 0; else throw e;
      }
      if (bytesRead > 0) {
        result = buf.slice(0, bytesRead).toString("utf-8");
      }
    } else if (typeof window != "undefined" && typeof window.prompt == "function") {
      result = window.prompt("Input: ");
      if (result !== null) {
        result += "\n";
      }
    } else {}
    if (!result) {
      return null;
    }
    FS_stdin_getChar_buffer = intArrayFromString(result, true);
  }
  return FS_stdin_getChar_buffer.shift();
};

var TTY = {
  ttys: [],
  init() {},
  shutdown() {},
  register(dev, ops) {
    TTY.ttys[dev] = {
      input: [],
      output: [],
      ops: ops
    };
    FS.registerDevice(dev, TTY.stream_ops);
  },
  stream_ops: {
    open(stream) {
      var tty = TTY.ttys[stream.node.rdev];
      if (!tty) {
        throw new FS.ErrnoError(43);
      }
      stream.tty = tty;
      stream.seekable = false;
    },
    close(stream) {
      stream.tty.ops.fsync(stream.tty);
    },
    fsync(stream) {
      stream.tty.ops.fsync(stream.tty);
    },
    read(stream, buffer, offset, length, pos) {
      /* ignored */ if (!stream.tty || !stream.tty.ops.get_char) {
        throw new FS.ErrnoError(60);
      }
      var bytesRead = 0;
      for (var i = 0; i < length; i++) {
        var result;
        try {
          result = stream.tty.ops.get_char(stream.tty);
        } catch (e) {
          throw new FS.ErrnoError(29);
        }
        if (result === undefined && bytesRead === 0) {
          throw new FS.ErrnoError(6);
        }
        if (result === null || result === undefined) break;
        bytesRead++;
        buffer[offset + i] = result;
      }
      if (bytesRead) {
        stream.node.timestamp = Date.now();
      }
      return bytesRead;
    },
    write(stream, buffer, offset, length, pos) {
      if (!stream.tty || !stream.tty.ops.put_char) {
        throw new FS.ErrnoError(60);
      }
      try {
        for (var i = 0; i < length; i++) {
          stream.tty.ops.put_char(stream.tty, buffer[offset + i]);
        }
      } catch (e) {
        throw new FS.ErrnoError(29);
      }
      if (length) {
        stream.node.timestamp = Date.now();
      }
      return i;
    }
  },
  default_tty_ops: {
    get_char(tty) {
      return FS_stdin_getChar();
    },
    put_char(tty, val) {
      if (val === null || val === 10) {
        out(UTF8ArrayToString(tty.output, 0));
        tty.output = [];
      } else {
        if (val != 0) tty.output.push(val);
      }
    },
    fsync(tty) {
      if (tty.output && tty.output.length > 0) {
        out(UTF8ArrayToString(tty.output, 0));
        tty.output = [];
      }
    },
    ioctl_tcgets(tty) {
      return {
        c_iflag: 25856,
        c_oflag: 5,
        c_cflag: 191,
        c_lflag: 35387,
        c_cc: [ 3, 28, 127, 21, 4, 0, 1, 0, 17, 19, 26, 0, 18, 15, 23, 22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ]
      };
    },
    ioctl_tcsets(tty, optional_actions, data) {
      return 0;
    },
    ioctl_tiocgwinsz(tty) {
      return [ 24, 80 ];
    }
  },
  default_tty1_ops: {
    put_char(tty, val) {
      if (val === null || val === 10) {
        err(UTF8ArrayToString(tty.output, 0));
        tty.output = [];
      } else {
        if (val != 0) tty.output.push(val);
      }
    },
    fsync(tty) {
      if (tty.output && tty.output.length > 0) {
        err(UTF8ArrayToString(tty.output, 0));
        tty.output = [];
      }
    }
  }
};

var mmapAlloc = size => {
  abort();
};

var MEMFS = {
  ops_table: null,
  mount(mount) {
    return MEMFS.createNode(null, "/", 16384 | 511, /* 0777 */ 0);
  },
  createNode(parent, name, mode, dev) {
    if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
      throw new FS.ErrnoError(63);
    }
    MEMFS.ops_table ||= {
      dir: {
        node: {
          getattr: MEMFS.node_ops.getattr,
          setattr: MEMFS.node_ops.setattr,
          lookup: MEMFS.node_ops.lookup,
          mknod: MEMFS.node_ops.mknod,
          rename: MEMFS.node_ops.rename,
          unlink: MEMFS.node_ops.unlink,
          rmdir: MEMFS.node_ops.rmdir,
          readdir: MEMFS.node_ops.readdir,
          symlink: MEMFS.node_ops.symlink
        },
        stream: {
          llseek: MEMFS.stream_ops.llseek
        }
      },
      file: {
        node: {
          getattr: MEMFS.node_ops.getattr,
          setattr: MEMFS.node_ops.setattr
        },
        stream: {
          llseek: MEMFS.stream_ops.llseek,
          read: MEMFS.stream_ops.read,
          write: MEMFS.stream_ops.write,
          allocate: MEMFS.stream_ops.allocate,
          mmap: MEMFS.stream_ops.mmap,
          msync: MEMFS.stream_ops.msync
        }
      },
      link: {
        node: {
          getattr: MEMFS.node_ops.getattr,
          setattr: MEMFS.node_ops.setattr,
          readlink: MEMFS.node_ops.readlink
        },
        stream: {}
      },
      chrdev: {
        node: {
          getattr: MEMFS.node_ops.getattr,
          setattr: MEMFS.node_ops.setattr
        },
        stream: FS.chrdev_stream_ops
      }
    };
    var node = FS.createNode(parent, name, mode, dev);
    if (FS.isDir(node.mode)) {
      node.node_ops = MEMFS.ops_table.dir.node;
      node.stream_ops = MEMFS.ops_table.dir.stream;
      node.contents = {};
    } else if (FS.isFile(node.mode)) {
      node.node_ops = MEMFS.ops_table.file.node;
      node.stream_ops = MEMFS.ops_table.file.stream;
      node.usedBytes = 0;
      node.contents = null;
    } else if (FS.isLink(node.mode)) {
      node.node_ops = MEMFS.ops_table.link.node;
      node.stream_ops = MEMFS.ops_table.link.stream;
    } else if (FS.isChrdev(node.mode)) {
      node.node_ops = MEMFS.ops_table.chrdev.node;
      node.stream_ops = MEMFS.ops_table.chrdev.stream;
    }
    node.timestamp = Date.now();
    if (parent) {
      parent.contents[name] = node;
      parent.timestamp = node.timestamp;
    }
    return node;
  },
  getFileDataAsTypedArray(node) {
    if (!node.contents) return new Uint8Array(0);
    if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes);
    return new Uint8Array(node.contents);
  },
  expandFileStorage(node, newCapacity) {
    var prevCapacity = node.contents ? node.contents.length : 0;
    if (prevCapacity >= newCapacity) return;
    var CAPACITY_DOUBLING_MAX = 1024 * 1024;
    newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2 : 1.125)) >>> 0);
    if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256);
    var oldContents = node.contents;
    node.contents = new Uint8Array(newCapacity);
    if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0);
  },
  resizeFileStorage(node, newSize) {
    if (node.usedBytes == newSize) return;
    if (newSize == 0) {
      node.contents = null;
      node.usedBytes = 0;
    } else {
      var oldContents = node.contents;
      node.contents = new Uint8Array(newSize);
      if (oldContents) {
        node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes)));
      }
      node.usedBytes = newSize;
    }
  },
  node_ops: {
    getattr(node) {
      var attr = {};
      attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
      attr.ino = node.id;
      attr.mode = node.mode;
      attr.nlink = 1;
      attr.uid = 0;
      attr.gid = 0;
      attr.rdev = node.rdev;
      if (FS.isDir(node.mode)) {
        attr.size = 4096;
      } else if (FS.isFile(node.mode)) {
        attr.size = node.usedBytes;
      } else if (FS.isLink(node.mode)) {
        attr.size = node.link.length;
      } else {
        attr.size = 0;
      }
      attr.atime = new Date(node.timestamp);
      attr.mtime = new Date(node.timestamp);
      attr.ctime = new Date(node.timestamp);
      attr.blksize = 4096;
      attr.blocks = Math.ceil(attr.size / attr.blksize);
      return attr;
    },
    setattr(node, attr) {
      if (attr.mode !== undefined) {
        node.mode = attr.mode;
      }
      if (attr.timestamp !== undefined) {
        node.timestamp = attr.timestamp;
      }
      if (attr.size !== undefined) {
        MEMFS.resizeFileStorage(node, attr.size);
      }
    },
    lookup(parent, name) {
      throw FS.genericErrors[44];
    },
    mknod(parent, name, mode, dev) {
      return MEMFS.createNode(parent, name, mode, dev);
    },
    rename(old_node, new_dir, new_name) {
      if (FS.isDir(old_node.mode)) {
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {}
        if (new_node) {
          for (var i in new_node.contents) {
            throw new FS.ErrnoError(55);
          }
        }
      }
      delete old_node.parent.contents[old_node.name];
      old_node.parent.timestamp = Date.now();
      old_node.name = new_name;
      new_dir.contents[new_name] = old_node;
      new_dir.timestamp = old_node.parent.timestamp;
    },
    unlink(parent, name) {
      delete parent.contents[name];
      parent.timestamp = Date.now();
    },
    rmdir(parent, name) {
      var node = FS.lookupNode(parent, name);
      for (var i in node.contents) {
        throw new FS.ErrnoError(55);
      }
      delete parent.contents[name];
      parent.timestamp = Date.now();
    },
    readdir(node) {
      var entries = [ ".", ".." ];
      for (var key of Object.keys(node.contents)) {
        entries.push(key);
      }
      return entries;
    },
    symlink(parent, newname, oldpath) {
      var node = MEMFS.createNode(parent, newname, 511 | /* 0777 */ 40960, 0);
      node.link = oldpath;
      return node;
    },
    readlink(node) {
      if (!FS.isLink(node.mode)) {
        throw new FS.ErrnoError(28);
      }
      return node.link;
    }
  },
  stream_ops: {
    read(stream, buffer, offset, length, position) {
      var contents = stream.node.contents;
      if (position >= stream.node.usedBytes) return 0;
      var size = Math.min(stream.node.usedBytes - position, length);
      if (size > 8 && contents.subarray) {
        buffer.set(contents.subarray(position, position + size), offset);
      } else {
        for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
      }
      return size;
    },
    write(stream, buffer, offset, length, position, canOwn) {
      if (buffer.buffer === HEAP8.buffer) {
        canOwn = false;
      }
      if (!length) return 0;
      var node = stream.node;
      node.timestamp = Date.now();
      if (buffer.subarray && (!node.contents || node.contents.subarray)) {
        if (canOwn) {
          node.contents = buffer.subarray(offset, offset + length);
          node.usedBytes = length;
          return length;
        } else if (node.usedBytes === 0 && position === 0) {
          node.contents = buffer.slice(offset, offset + length);
          node.usedBytes = length;
          return length;
        } else if (position + length <= node.usedBytes) {
          node.contents.set(buffer.subarray(offset, offset + length), position);
          return length;
        }
      }
      MEMFS.expandFileStorage(node, position + length);
      if (node.contents.subarray && buffer.subarray) {
        node.contents.set(buffer.subarray(offset, offset + length), position);
      } else {
        for (var i = 0; i < length; i++) {
          node.contents[position + i] = buffer[offset + i];
        }
      }
      node.usedBytes = Math.max(node.usedBytes, position + length);
      return length;
    },
    llseek(stream, offset, whence) {
      var position = offset;
      if (whence === 1) {
        position += stream.position;
      } else if (whence === 2) {
        if (FS.isFile(stream.node.mode)) {
          position += stream.node.usedBytes;
        }
      }
      if (position < 0) {
        throw new FS.ErrnoError(28);
      }
      return position;
    },
    allocate(stream, offset, length) {
      MEMFS.expandFileStorage(stream.node, offset + length);
      stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
    },
    mmap(stream, length, position, prot, flags) {
      if (!FS.isFile(stream.node.mode)) {
        throw new FS.ErrnoError(43);
      }
      var ptr;
      var allocated;
      var contents = stream.node.contents;
      if (!(flags & 2) && contents.buffer === HEAP8.buffer) {
        allocated = false;
        ptr = contents.byteOffset;
      } else {
        if (position > 0 || position + length < contents.length) {
          if (contents.subarray) {
            contents = contents.subarray(position, position + length);
          } else {
            contents = Array.prototype.slice.call(contents, position, position + length);
          }
        }
        allocated = true;
        ptr = mmapAlloc(length);
        if (!ptr) {
          throw new FS.ErrnoError(48);
        }
        HEAP8.set(contents, ptr);
      }
      return {
        ptr: ptr,
        allocated: allocated
      };
    },
    msync(stream, buffer, offset, length, mmapFlags) {
      MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
      return 0;
    }
  }
};

/** @param {boolean=} noRunDep */ var asyncLoad = (url, onload, onerror, noRunDep) => {
  var dep = !noRunDep ? getUniqueRunDependency(`al ${url}`) : "";
  readAsync(url, arrayBuffer => {
    onload(new Uint8Array(arrayBuffer));
    if (dep) removeRunDependency(dep);
  }, event => {
    if (onerror) {
      onerror();
    } else {
      throw `Loading data file "${url}" failed.`;
    }
  });
  if (dep) addRunDependency(dep);
};

var FS_createDataFile = (parent, name, fileData, canRead, canWrite, canOwn) => {
  FS.createDataFile(parent, name, fileData, canRead, canWrite, canOwn);
};

var preloadPlugins = Module["preloadPlugins"] || [];

var FS_handledByPreloadPlugin = (byteArray, fullname, finish, onerror) => {
  if (typeof Browser != "undefined") Browser.init();
  var handled = false;
  preloadPlugins.forEach(plugin => {
    if (handled) return;
    if (plugin["canHandle"](fullname)) {
      plugin["handle"](byteArray, fullname, finish, onerror);
      handled = true;
    }
  });
  return handled;
};

var FS_createPreloadedFile = (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) => {
  var fullname = name ? PATH_FS.resolve(PATH.join2(parent, name)) : parent;
  var dep = getUniqueRunDependency(`cp ${fullname}`);
  function processData(byteArray) {
    function finish(byteArray) {
      preFinish?.();
      if (!dontCreateFile) {
        FS_createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
      }
      onload?.();
      removeRunDependency(dep);
    }
    if (FS_handledByPreloadPlugin(byteArray, fullname, finish, () => {
      onerror?.();
      removeRunDependency(dep);
    })) {
      return;
    }
    finish(byteArray);
  }
  addRunDependency(dep);
  if (typeof url == "string") {
    asyncLoad(url, processData, onerror);
  } else {
    processData(url);
  }
};

var FS_modeStringToFlags = str => {
  var flagModes = {
    "r": 0,
    "r+": 2,
    "w": 512 | 64 | 1,
    "w+": 512 | 64 | 2,
    "a": 1024 | 64 | 1,
    "a+": 1024 | 64 | 2
  };
  var flags = flagModes[str];
  if (typeof flags == "undefined") {
    throw new Error(`Unknown file open mode: ${str}`);
  }
  return flags;
};

var FS_getMode = (canRead, canWrite) => {
  var mode = 0;
  if (canRead) mode |= 292 | 73;
  if (canWrite) mode |= 146;
  return mode;
};

var FS = {
  root: null,
  mounts: [],
  devices: {},
  streams: [],
  nextInode: 1,
  nameTable: null,
  currentPath: "/",
  initialized: false,
  ignorePermissions: true,
  ErrnoError: class {
    constructor(errno) {
      this.name = "ErrnoError";
      this.errno = errno;
    }
  },
  genericErrors: {},
  filesystems: null,
  syncFSRequests: 0,
  FSStream: class {
    constructor() {
      this.shared = {};
    }
    get object() {
      return this.node;
    }
    set object(val) {
      this.node = val;
    }
    get isRead() {
      return (this.flags & 2097155) !== 1;
    }
    get isWrite() {
      return (this.flags & 2097155) !== 0;
    }
    get isAppend() {
      return (this.flags & 1024);
    }
    get flags() {
      return this.shared.flags;
    }
    set flags(val) {
      this.shared.flags = val;
    }
    get position() {
      return this.shared.position;
    }
    set position(val) {
      this.shared.position = val;
    }
  },
  FSNode: class {
    constructor(parent, name, mode, rdev) {
      if (!parent) {
        parent = this;
      }
      this.parent = parent;
      this.mount = parent.mount;
      this.mounted = null;
      this.id = FS.nextInode++;
      this.name = name;
      this.mode = mode;
      this.node_ops = {};
      this.stream_ops = {};
      this.rdev = rdev;
      this.readMode = 292 | /*292*/ 73;
      /*73*/ this.writeMode = 146;
    }
    /*146*/ get read() {
      return (this.mode & this.readMode) === this.readMode;
    }
    set read(val) {
      val ? this.mode |= this.readMode : this.mode &= ~this.readMode;
    }
    get write() {
      return (this.mode & this.writeMode) === this.writeMode;
    }
    set write(val) {
      val ? this.mode |= this.writeMode : this.mode &= ~this.writeMode;
    }
    get isFolder() {
      return FS.isDir(this.mode);
    }
    get isDevice() {
      return FS.isChrdev(this.mode);
    }
  },
  lookupPath(path, opts = {}) {
    path = PATH_FS.resolve(path);
    if (!path) return {
      path: "",
      node: null
    };
    var defaults = {
      follow_mount: true,
      recurse_count: 0
    };
    opts = Object.assign(defaults, opts);
    if (opts.recurse_count > 8) {
      throw new FS.ErrnoError(32);
    }
    var parts = path.split("/").filter(p => !!p);
    var current = FS.root;
    var current_path = "/";
    for (var i = 0; i < parts.length; i++) {
      var islast = (i === parts.length - 1);
      if (islast && opts.parent) {
        break;
      }
      current = FS.lookupNode(current, parts[i]);
      current_path = PATH.join2(current_path, parts[i]);
      if (FS.isMountpoint(current)) {
        if (!islast || (islast && opts.follow_mount)) {
          current = current.mounted.root;
        }
      }
      if (!islast || opts.follow) {
        var count = 0;
        while (FS.isLink(current.mode)) {
          var link = FS.readlink(current_path);
          current_path = PATH_FS.resolve(PATH.dirname(current_path), link);
          var lookup = FS.lookupPath(current_path, {
            recurse_count: opts.recurse_count + 1
          });
          current = lookup.node;
          if (count++ > 40) {
            throw new FS.ErrnoError(32);
          }
        }
      }
    }
    return {
      path: current_path,
      node: current
    };
  },
  getPath(node) {
    var path;
    while (true) {
      if (FS.isRoot(node)) {
        var mount = node.mount.mountpoint;
        if (!path) return mount;
        return mount[mount.length - 1] !== "/" ? `${mount}/${path}` : mount + path;
      }
      path = path ? `${node.name}/${path}` : node.name;
      node = node.parent;
    }
  },
  hashName(parentid, name) {
    var hash = 0;
    for (var i = 0; i < name.length; i++) {
      hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
    }
    return ((parentid + hash) >>> 0) % FS.nameTable.length;
  },
  hashAddNode(node) {
    var hash = FS.hashName(node.parent.id, node.name);
    node.name_next = FS.nameTable[hash];
    FS.nameTable[hash] = node;
  },
  hashRemoveNode(node) {
    var hash = FS.hashName(node.parent.id, node.name);
    if (FS.nameTable[hash] === node) {
      FS.nameTable[hash] = node.name_next;
    } else {
      var current = FS.nameTable[hash];
      while (current) {
        if (current.name_next === node) {
          current.name_next = node.name_next;
          break;
        }
        current = current.name_next;
      }
    }
  },
  lookupNode(parent, name) {
    var errCode = FS.mayLookup(parent);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    var hash = FS.hashName(parent.id, name);
    for (var node = FS.nameTable[hash]; node; node = node.name_next) {
      var nodeName = node.name;
      if (node.parent.id === parent.id && nodeName === name) {
        return node;
      }
    }
    return FS.lookup(parent, name);
  },
  createNode(parent, name, mode, rdev) {
    var node = new FS.FSNode(parent, name, mode, rdev);
    FS.hashAddNode(node);
    return node;
  },
  destroyNode(node) {
    FS.hashRemoveNode(node);
  },
  isRoot(node) {
    return node === node.parent;
  },
  isMountpoint(node) {
    return !!node.mounted;
  },
  isFile(mode) {
    return (mode & 61440) === 32768;
  },
  isDir(mode) {
    return (mode & 61440) === 16384;
  },
  isLink(mode) {
    return (mode & 61440) === 40960;
  },
  isChrdev(mode) {
    return (mode & 61440) === 8192;
  },
  isBlkdev(mode) {
    return (mode & 61440) === 24576;
  },
  isFIFO(mode) {
    return (mode & 61440) === 4096;
  },
  isSocket(mode) {
    return (mode & 49152) === 49152;
  },
  flagsToPermissionString(flag) {
    var perms = [ "r", "w", "rw" ][flag & 3];
    if ((flag & 512)) {
      perms += "w";
    }
    return perms;
  },
  nodePermissions(node, perms) {
    if (FS.ignorePermissions) {
      return 0;
    }
    if (perms.includes("r") && !(node.mode & 292)) {
      return 2;
    } else if (perms.includes("w") && !(node.mode & 146)) {
      return 2;
    } else if (perms.includes("x") && !(node.mode & 73)) {
      return 2;
    }
    return 0;
  },
  mayLookup(dir) {
    if (!FS.isDir(dir.mode)) return 54;
    var errCode = FS.nodePermissions(dir, "x");
    if (errCode) return errCode;
    if (!dir.node_ops.lookup) return 2;
    return 0;
  },
  mayCreate(dir, name) {
    try {
      var node = FS.lookupNode(dir, name);
      return 20;
    } catch (e) {}
    return FS.nodePermissions(dir, "wx");
  },
  mayDelete(dir, name, isdir) {
    var node;
    try {
      node = FS.lookupNode(dir, name);
    } catch (e) {
      return e.errno;
    }
    var errCode = FS.nodePermissions(dir, "wx");
    if (errCode) {
      return errCode;
    }
    if (isdir) {
      if (!FS.isDir(node.mode)) {
        return 54;
      }
      if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
        return 10;
      }
    } else {
      if (FS.isDir(node.mode)) {
        return 31;
      }
    }
    return 0;
  },
  mayOpen(node, flags) {
    if (!node) {
      return 44;
    }
    if (FS.isLink(node.mode)) {
      return 32;
    } else if (FS.isDir(node.mode)) {
      if (FS.flagsToPermissionString(flags) !== "r" || (flags & 512)) {
        return 31;
      }
    }
    return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
  },
  MAX_OPEN_FDS: 4096,
  nextfd() {
    for (var fd = 0; fd <= FS.MAX_OPEN_FDS; fd++) {
      if (!FS.streams[fd]) {
        return fd;
      }
    }
    throw new FS.ErrnoError(33);
  },
  getStreamChecked(fd) {
    var stream = FS.getStream(fd);
    if (!stream) {
      throw new FS.ErrnoError(8);
    }
    return stream;
  },
  getStream: fd => FS.streams[fd],
  createStream(stream, fd = -1) {
    stream = Object.assign(new FS.FSStream, stream);
    if (fd == -1) {
      fd = FS.nextfd();
    }
    stream.fd = fd;
    FS.streams[fd] = stream;
    return stream;
  },
  closeStream(fd) {
    FS.streams[fd] = null;
  },
  dupStream(origStream, fd = -1) {
    var stream = FS.createStream(origStream, fd);
    stream.stream_ops?.dup?.(stream);
    return stream;
  },
  chrdev_stream_ops: {
    open(stream) {
      var device = FS.getDevice(stream.node.rdev);
      stream.stream_ops = device.stream_ops;
      stream.stream_ops.open?.(stream);
    },
    llseek() {
      throw new FS.ErrnoError(70);
    }
  },
  major: dev => ((dev) >> 8),
  minor: dev => ((dev) & 255),
  makedev: (ma, mi) => ((ma) << 8 | (mi)),
  registerDevice(dev, ops) {
    FS.devices[dev] = {
      stream_ops: ops
    };
  },
  getDevice: dev => FS.devices[dev],
  getMounts(mount) {
    var mounts = [];
    var check = [ mount ];
    while (check.length) {
      var m = check.pop();
      mounts.push(m);
      check.push(...m.mounts);
    }
    return mounts;
  },
  syncfs(populate, callback) {
    if (typeof populate == "function") {
      callback = populate;
      populate = false;
    }
    FS.syncFSRequests++;
    if (FS.syncFSRequests > 1) {
      err(`warning: ${FS.syncFSRequests} FS.syncfs operations in flight at once, probably just doing extra work`);
    }
    var mounts = FS.getMounts(FS.root.mount);
    var completed = 0;
    function doCallback(errCode) {
      FS.syncFSRequests--;
      return callback(errCode);
    }
    function done(errCode) {
      if (errCode) {
        if (!done.errored) {
          done.errored = true;
          return doCallback(errCode);
        }
        return;
      }
      if (++completed >= mounts.length) {
        doCallback(null);
      }
    }
    mounts.forEach(mount => {
      if (!mount.type.syncfs) {
        return done(null);
      }
      mount.type.syncfs(mount, populate, done);
    });
  },
  mount(type, opts, mountpoint) {
    var root = mountpoint === "/";
    var pseudo = !mountpoint;
    var node;
    if (root && FS.root) {
      throw new FS.ErrnoError(10);
    } else if (!root && !pseudo) {
      var lookup = FS.lookupPath(mountpoint, {
        follow_mount: false
      });
      mountpoint = lookup.path;
      node = lookup.node;
      if (FS.isMountpoint(node)) {
        throw new FS.ErrnoError(10);
      }
      if (!FS.isDir(node.mode)) {
        throw new FS.ErrnoError(54);
      }
    }
    var mount = {
      type: type,
      opts: opts,
      mountpoint: mountpoint,
      mounts: []
    };
    var mountRoot = type.mount(mount);
    mountRoot.mount = mount;
    mount.root = mountRoot;
    if (root) {
      FS.root = mountRoot;
    } else if (node) {
      node.mounted = mount;
      if (node.mount) {
        node.mount.mounts.push(mount);
      }
    }
    return mountRoot;
  },
  unmount(mountpoint) {
    var lookup = FS.lookupPath(mountpoint, {
      follow_mount: false
    });
    if (!FS.isMountpoint(lookup.node)) {
      throw new FS.ErrnoError(28);
    }
    var node = lookup.node;
    var mount = node.mounted;
    var mounts = FS.getMounts(mount);
    Object.keys(FS.nameTable).forEach(hash => {
      var current = FS.nameTable[hash];
      while (current) {
        var next = current.name_next;
        if (mounts.includes(current.mount)) {
          FS.destroyNode(current);
        }
        current = next;
      }
    });
    node.mounted = null;
    var idx = node.mount.mounts.indexOf(mount);
    node.mount.mounts.splice(idx, 1);
  },
  lookup(parent, name) {
    return parent.node_ops.lookup(parent, name);
  },
  mknod(path, mode, dev) {
    var lookup = FS.lookupPath(path, {
      parent: true
    });
    var parent = lookup.node;
    var name = PATH.basename(path);
    if (!name || name === "." || name === "..") {
      throw new FS.ErrnoError(28);
    }
    var errCode = FS.mayCreate(parent, name);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    if (!parent.node_ops.mknod) {
      throw new FS.ErrnoError(63);
    }
    return parent.node_ops.mknod(parent, name, mode, dev);
  },
  create(path, mode) {
    mode = mode !== undefined ? mode : 438;
    /* 0666 */ mode &= 4095;
    mode |= 32768;
    return FS.mknod(path, mode, 0);
  },
  mkdir(path, mode) {
    mode = mode !== undefined ? mode : 511;
    /* 0777 */ mode &= 511 | 512;
    mode |= 16384;
    return FS.mknod(path, mode, 0);
  },
  mkdirTree(path, mode) {
    var dirs = path.split("/");
    var d = "";
    for (var i = 0; i < dirs.length; ++i) {
      if (!dirs[i]) continue;
      d += "/" + dirs[i];
      try {
        FS.mkdir(d, mode);
      } catch (e) {
        if (e.errno != 20) throw e;
      }
    }
  },
  mkdev(path, mode, dev) {
    if (typeof dev == "undefined") {
      dev = mode;
      mode = 438;
    }
    /* 0666 */ mode |= 8192;
    return FS.mknod(path, mode, dev);
  },
  symlink(oldpath, newpath) {
    if (!PATH_FS.resolve(oldpath)) {
      throw new FS.ErrnoError(44);
    }
    var lookup = FS.lookupPath(newpath, {
      parent: true
    });
    var parent = lookup.node;
    if (!parent) {
      throw new FS.ErrnoError(44);
    }
    var newname = PATH.basename(newpath);
    var errCode = FS.mayCreate(parent, newname);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    if (!parent.node_ops.symlink) {
      throw new FS.ErrnoError(63);
    }
    return parent.node_ops.symlink(parent, newname, oldpath);
  },
  rename(old_path, new_path) {
    var old_dirname = PATH.dirname(old_path);
    var new_dirname = PATH.dirname(new_path);
    var old_name = PATH.basename(old_path);
    var new_name = PATH.basename(new_path);
    var lookup, old_dir, new_dir;
    lookup = FS.lookupPath(old_path, {
      parent: true
    });
    old_dir = lookup.node;
    lookup = FS.lookupPath(new_path, {
      parent: true
    });
    new_dir = lookup.node;
    if (!old_dir || !new_dir) throw new FS.ErrnoError(44);
    if (old_dir.mount !== new_dir.mount) {
      throw new FS.ErrnoError(75);
    }
    var old_node = FS.lookupNode(old_dir, old_name);
    var relative = PATH_FS.relative(old_path, new_dirname);
    if (relative.charAt(0) !== ".") {
      throw new FS.ErrnoError(28);
    }
    relative = PATH_FS.relative(new_path, old_dirname);
    if (relative.charAt(0) !== ".") {
      throw new FS.ErrnoError(55);
    }
    var new_node;
    try {
      new_node = FS.lookupNode(new_dir, new_name);
    } catch (e) {}
    if (old_node === new_node) {
      return;
    }
    var isdir = FS.isDir(old_node.mode);
    var errCode = FS.mayDelete(old_dir, old_name, isdir);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    errCode = new_node ? FS.mayDelete(new_dir, new_name, isdir) : FS.mayCreate(new_dir, new_name);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    if (!old_dir.node_ops.rename) {
      throw new FS.ErrnoError(63);
    }
    if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
      throw new FS.ErrnoError(10);
    }
    if (new_dir !== old_dir) {
      errCode = FS.nodePermissions(old_dir, "w");
      if (errCode) {
        throw new FS.ErrnoError(errCode);
      }
    }
    FS.hashRemoveNode(old_node);
    try {
      old_dir.node_ops.rename(old_node, new_dir, new_name);
      old_node.parent = new_dir;
    } catch (e) {
      throw e;
    } finally {
      FS.hashAddNode(old_node);
    }
  },
  rmdir(path) {
    var lookup = FS.lookupPath(path, {
      parent: true
    });
    var parent = lookup.node;
    var name = PATH.basename(path);
    var node = FS.lookupNode(parent, name);
    var errCode = FS.mayDelete(parent, name, true);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    if (!parent.node_ops.rmdir) {
      throw new FS.ErrnoError(63);
    }
    if (FS.isMountpoint(node)) {
      throw new FS.ErrnoError(10);
    }
    parent.node_ops.rmdir(parent, name);
    FS.destroyNode(node);
  },
  readdir(path) {
    var lookup = FS.lookupPath(path, {
      follow: true
    });
    var node = lookup.node;
    if (!node.node_ops.readdir) {
      throw new FS.ErrnoError(54);
    }
    return node.node_ops.readdir(node);
  },
  unlink(path) {
    var lookup = FS.lookupPath(path, {
      parent: true
    });
    var parent = lookup.node;
    if (!parent) {
      throw new FS.ErrnoError(44);
    }
    var name = PATH.basename(path);
    var node = FS.lookupNode(parent, name);
    var errCode = FS.mayDelete(parent, name, false);
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    if (!parent.node_ops.unlink) {
      throw new FS.ErrnoError(63);
    }
    if (FS.isMountpoint(node)) {
      throw new FS.ErrnoError(10);
    }
    parent.node_ops.unlink(parent, name);
    FS.destroyNode(node);
  },
  readlink(path) {
    var lookup = FS.lookupPath(path);
    var link = lookup.node;
    if (!link) {
      throw new FS.ErrnoError(44);
    }
    if (!link.node_ops.readlink) {
      throw new FS.ErrnoError(28);
    }
    return PATH_FS.resolve(FS.getPath(link.parent), link.node_ops.readlink(link));
  },
  stat(path, dontFollow) {
    var lookup = FS.lookupPath(path, {
      follow: !dontFollow
    });
    var node = lookup.node;
    if (!node) {
      throw new FS.ErrnoError(44);
    }
    if (!node.node_ops.getattr) {
      throw new FS.ErrnoError(63);
    }
    return node.node_ops.getattr(node);
  },
  lstat(path) {
    return FS.stat(path, true);
  },
  chmod(path, mode, dontFollow) {
    var node;
    if (typeof path == "string") {
      var lookup = FS.lookupPath(path, {
        follow: !dontFollow
      });
      node = lookup.node;
    } else {
      node = path;
    }
    if (!node.node_ops.setattr) {
      throw new FS.ErrnoError(63);
    }
    node.node_ops.setattr(node, {
      mode: (mode & 4095) | (node.mode & ~4095),
      timestamp: Date.now()
    });
  },
  lchmod(path, mode) {
    FS.chmod(path, mode, true);
  },
  fchmod(fd, mode) {
    var stream = FS.getStreamChecked(fd);
    FS.chmod(stream.node, mode);
  },
  chown(path, uid, gid, dontFollow) {
    var node;
    if (typeof path == "string") {
      var lookup = FS.lookupPath(path, {
        follow: !dontFollow
      });
      node = lookup.node;
    } else {
      node = path;
    }
    if (!node.node_ops.setattr) {
      throw new FS.ErrnoError(63);
    }
    node.node_ops.setattr(node, {
      timestamp: Date.now()
    });
  },
  lchown(path, uid, gid) {
    FS.chown(path, uid, gid, true);
  },
  fchown(fd, uid, gid) {
    var stream = FS.getStreamChecked(fd);
    FS.chown(stream.node, uid, gid);
  },
  truncate(path, len) {
    if (len < 0) {
      throw new FS.ErrnoError(28);
    }
    var node;
    if (typeof path == "string") {
      var lookup = FS.lookupPath(path, {
        follow: true
      });
      node = lookup.node;
    } else {
      node = path;
    }
    if (!node.node_ops.setattr) {
      throw new FS.ErrnoError(63);
    }
    if (FS.isDir(node.mode)) {
      throw new FS.ErrnoError(31);
    }
    if (!FS.isFile(node.mode)) {
      throw new FS.ErrnoError(28);
    }
    var errCode = FS.nodePermissions(node, "w");
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    node.node_ops.setattr(node, {
      size: len,
      timestamp: Date.now()
    });
  },
  ftruncate(fd, len) {
    var stream = FS.getStreamChecked(fd);
    if ((stream.flags & 2097155) === 0) {
      throw new FS.ErrnoError(28);
    }
    FS.truncate(stream.node, len);
  },
  utime(path, atime, mtime) {
    var lookup = FS.lookupPath(path, {
      follow: true
    });
    var node = lookup.node;
    node.node_ops.setattr(node, {
      timestamp: Math.max(atime, mtime)
    });
  },
  open(path, flags, mode) {
    if (path === "") {
      throw new FS.ErrnoError(44);
    }
    flags = typeof flags == "string" ? FS_modeStringToFlags(flags) : flags;
    if ((flags & 64)) {
      mode = typeof mode == "undefined" ? 438 : /* 0666 */ mode;
      mode = (mode & 4095) | 32768;
    } else {
      mode = 0;
    }
    var node;
    if (typeof path == "object") {
      node = path;
    } else {
      path = PATH.normalize(path);
      try {
        var lookup = FS.lookupPath(path, {
          follow: !(flags & 131072)
        });
        node = lookup.node;
      } catch (e) {}
    }
    var created = false;
    if ((flags & 64)) {
      if (node) {
        if ((flags & 128)) {
          throw new FS.ErrnoError(20);
        }
      } else {
        node = FS.mknod(path, mode, 0);
        created = true;
      }
    }
    if (!node) {
      throw new FS.ErrnoError(44);
    }
    if (FS.isChrdev(node.mode)) {
      flags &= ~512;
    }
    if ((flags & 65536) && !FS.isDir(node.mode)) {
      throw new FS.ErrnoError(54);
    }
    if (!created) {
      var errCode = FS.mayOpen(node, flags);
      if (errCode) {
        throw new FS.ErrnoError(errCode);
      }
    }
    if ((flags & 512) && !created) {
      FS.truncate(node, 0);
    }
    flags &= ~(128 | 512 | 131072);
    var stream = FS.createStream({
      node: node,
      path: FS.getPath(node),
      flags: flags,
      seekable: true,
      position: 0,
      stream_ops: node.stream_ops,
      ungotten: [],
      error: false
    });
    if (stream.stream_ops.open) {
      stream.stream_ops.open(stream);
    }
    if (Module["logReadFiles"] && !(flags & 1)) {
      if (!FS.readFiles) FS.readFiles = {};
      if (!(path in FS.readFiles)) {
        FS.readFiles[path] = 1;
      }
    }
    return stream;
  },
  close(stream) {
    if (FS.isClosed(stream)) {
      throw new FS.ErrnoError(8);
    }
    if (stream.getdents) stream.getdents = null;
    try {
      if (stream.stream_ops.close) {
        stream.stream_ops.close(stream);
      }
    } catch (e) {
      throw e;
    } finally {
      FS.closeStream(stream.fd);
    }
    stream.fd = null;
  },
  isClosed(stream) {
    return stream.fd === null;
  },
  llseek(stream, offset, whence) {
    if (FS.isClosed(stream)) {
      throw new FS.ErrnoError(8);
    }
    if (!stream.seekable || !stream.stream_ops.llseek) {
      throw new FS.ErrnoError(70);
    }
    if (whence != 0 && whence != 1 && whence != 2) {
      throw new FS.ErrnoError(28);
    }
    stream.position = stream.stream_ops.llseek(stream, offset, whence);
    stream.ungotten = [];
    return stream.position;
  },
  read(stream, buffer, offset, length, position) {
    if (length < 0 || position < 0) {
      throw new FS.ErrnoError(28);
    }
    if (FS.isClosed(stream)) {
      throw new FS.ErrnoError(8);
    }
    if ((stream.flags & 2097155) === 1) {
      throw new FS.ErrnoError(8);
    }
    if (FS.isDir(stream.node.mode)) {
      throw new FS.ErrnoError(31);
    }
    if (!stream.stream_ops.read) {
      throw new FS.ErrnoError(28);
    }
    var seeking = typeof position != "undefined";
    if (!seeking) {
      position = stream.position;
    } else if (!stream.seekable) {
      throw new FS.ErrnoError(70);
    }
    var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
    if (!seeking) stream.position += bytesRead;
    return bytesRead;
  },
  write(stream, buffer, offset, length, position, canOwn) {
    if (length < 0 || position < 0) {
      throw new FS.ErrnoError(28);
    }
    if (FS.isClosed(stream)) {
      throw new FS.ErrnoError(8);
    }
    if ((stream.flags & 2097155) === 0) {
      throw new FS.ErrnoError(8);
    }
    if (FS.isDir(stream.node.mode)) {
      throw new FS.ErrnoError(31);
    }
    if (!stream.stream_ops.write) {
      throw new FS.ErrnoError(28);
    }
    if (stream.seekable && stream.flags & 1024) {
      FS.llseek(stream, 0, 2);
    }
    var seeking = typeof position != "undefined";
    if (!seeking) {
      position = stream.position;
    } else if (!stream.seekable) {
      throw new FS.ErrnoError(70);
    }
    var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
    if (!seeking) stream.position += bytesWritten;
    return bytesWritten;
  },
  allocate(stream, offset, length) {
    if (FS.isClosed(stream)) {
      throw new FS.ErrnoError(8);
    }
    if (offset < 0 || length <= 0) {
      throw new FS.ErrnoError(28);
    }
    if ((stream.flags & 2097155) === 0) {
      throw new FS.ErrnoError(8);
    }
    if (!FS.isFile(stream.node.mode) && !FS.isDir(stream.node.mode)) {
      throw new FS.ErrnoError(43);
    }
    if (!stream.stream_ops.allocate) {
      throw new FS.ErrnoError(138);
    }
    stream.stream_ops.allocate(stream, offset, length);
  },
  mmap(stream, length, position, prot, flags) {
    if ((prot & 2) !== 0 && (flags & 2) === 0 && (stream.flags & 2097155) !== 2) {
      throw new FS.ErrnoError(2);
    }
    if ((stream.flags & 2097155) === 1) {
      throw new FS.ErrnoError(2);
    }
    if (!stream.stream_ops.mmap) {
      throw new FS.ErrnoError(43);
    }
    return stream.stream_ops.mmap(stream, length, position, prot, flags);
  },
  msync(stream, buffer, offset, length, mmapFlags) {
    if (!stream.stream_ops.msync) {
      return 0;
    }
    return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
  },
  ioctl(stream, cmd, arg) {
    if (!stream.stream_ops.ioctl) {
      throw new FS.ErrnoError(59);
    }
    return stream.stream_ops.ioctl(stream, cmd, arg);
  },
  readFile(path, opts = {}) {
    opts.flags = opts.flags || 0;
    opts.encoding = opts.encoding || "binary";
    if (opts.encoding !== "utf8" && opts.encoding !== "binary") {
      throw new Error(`Invalid encoding type "${opts.encoding}"`);
    }
    var ret;
    var stream = FS.open(path, opts.flags);
    var stat = FS.stat(path);
    var length = stat.size;
    var buf = new Uint8Array(length);
    FS.read(stream, buf, 0, length, 0);
    if (opts.encoding === "utf8") {
      ret = UTF8ArrayToString(buf, 0);
    } else if (opts.encoding === "binary") {
      ret = buf;
    }
    FS.close(stream);
    return ret;
  },
  writeFile(path, data, opts = {}) {
    opts.flags = opts.flags || 577;
    var stream = FS.open(path, opts.flags, opts.mode);
    if (typeof data == "string") {
      var buf = new Uint8Array(lengthBytesUTF8(data) + 1);
      var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
      FS.write(stream, buf, 0, actualNumBytes, undefined, opts.canOwn);
    } else if (ArrayBuffer.isView(data)) {
      FS.write(stream, data, 0, data.byteLength, undefined, opts.canOwn);
    } else {
      throw new Error("Unsupported data type");
    }
    FS.close(stream);
  },
  cwd: () => FS.currentPath,
  chdir(path) {
    var lookup = FS.lookupPath(path, {
      follow: true
    });
    if (lookup.node === null) {
      throw new FS.ErrnoError(44);
    }
    if (!FS.isDir(lookup.node.mode)) {
      throw new FS.ErrnoError(54);
    }
    var errCode = FS.nodePermissions(lookup.node, "x");
    if (errCode) {
      throw new FS.ErrnoError(errCode);
    }
    FS.currentPath = lookup.path;
  },
  createDefaultDirectories() {
    FS.mkdir("/tmp");
    FS.mkdir("/home");
    FS.mkdir("/home/web_user");
  },
  createDefaultDevices() {
    FS.mkdir("/dev");
    FS.registerDevice(FS.makedev(1, 3), {
      read: () => 0,
      write: (stream, buffer, offset, length, pos) => length
    });
    FS.mkdev("/dev/null", FS.makedev(1, 3));
    TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
    TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
    FS.mkdev("/dev/tty", FS.makedev(5, 0));
    FS.mkdev("/dev/tty1", FS.makedev(6, 0));
    var randomBuffer = new Uint8Array(1024), randomLeft = 0;
    var randomByte = () => {
      if (randomLeft === 0) {
        randomLeft = randomFill(randomBuffer).byteLength;
      }
      return randomBuffer[--randomLeft];
    };
    FS.createDevice("/dev", "random", randomByte);
    FS.createDevice("/dev", "urandom", randomByte);
    FS.mkdir("/dev/shm");
    FS.mkdir("/dev/shm/tmp");
  },
  createSpecialDirectories() {
    FS.mkdir("/proc");
    var proc_self = FS.mkdir("/proc/self");
    FS.mkdir("/proc/self/fd");
    FS.mount({
      mount() {
        var node = FS.createNode(proc_self, "fd", 16384 | 511, /* 0777 */ 73);
        node.node_ops = {
          lookup(parent, name) {
            var fd = +name;
            var stream = FS.getStreamChecked(fd);
            var ret = {
              parent: null,
              mount: {
                mountpoint: "fake"
              },
              node_ops: {
                readlink: () => stream.path
              }
            };
            ret.parent = ret;
            return ret;
          }
        };
        return node;
      }
    }, {}, "/proc/self/fd");
  },
  createStandardStreams() {
    if (Module["stdin"]) {
      FS.createDevice("/dev", "stdin", Module["stdin"]);
    } else {
      FS.symlink("/dev/tty", "/dev/stdin");
    }
    if (Module["stdout"]) {
      FS.createDevice("/dev", "stdout", null, Module["stdout"]);
    } else {
      FS.symlink("/dev/tty", "/dev/stdout");
    }
    if (Module["stderr"]) {
      FS.createDevice("/dev", "stderr", null, Module["stderr"]);
    } else {
      FS.symlink("/dev/tty1", "/dev/stderr");
    }
    var stdin = FS.open("/dev/stdin", 0);
    var stdout = FS.open("/dev/stdout", 1);
    var stderr = FS.open("/dev/stderr", 1);
  },
  staticInit() {
    [ 44 ].forEach(code => {
      FS.genericErrors[code] = new FS.ErrnoError(code);
      FS.genericErrors[code].stack = "<generic error, no stack>";
    });
    FS.nameTable = new Array(4096);
    FS.mount(MEMFS, {}, "/");
    FS.createDefaultDirectories();
    FS.createDefaultDevices();
    FS.createSpecialDirectories();
    FS.filesystems = {
      "MEMFS": MEMFS
    };
  },
  init(input, output, error) {
    FS.init.initialized = true;
    Module["stdin"] = input || Module["stdin"];
    Module["stdout"] = output || Module["stdout"];
    Module["stderr"] = error || Module["stderr"];
    FS.createStandardStreams();
  },
  quit() {
    FS.init.initialized = false;
    for (var i = 0; i < FS.streams.length; i++) {
      var stream = FS.streams[i];
      if (!stream) {
        continue;
      }
      FS.close(stream);
    }
  },
  findObject(path, dontResolveLastLink) {
    var ret = FS.analyzePath(path, dontResolveLastLink);
    if (!ret.exists) {
      return null;
    }
    return ret.object;
  },
  analyzePath(path, dontResolveLastLink) {
    try {
      var lookup = FS.lookupPath(path, {
        follow: !dontResolveLastLink
      });
      path = lookup.path;
    } catch (e) {}
    var ret = {
      isRoot: false,
      exists: false,
      error: 0,
      name: null,
      path: null,
      object: null,
      parentExists: false,
      parentPath: null,
      parentObject: null
    };
    try {
      var lookup = FS.lookupPath(path, {
        parent: true
      });
      ret.parentExists = true;
      ret.parentPath = lookup.path;
      ret.parentObject = lookup.node;
      ret.name = PATH.basename(path);
      lookup = FS.lookupPath(path, {
        follow: !dontResolveLastLink
      });
      ret.exists = true;
      ret.path = lookup.path;
      ret.object = lookup.node;
      ret.name = lookup.node.name;
      ret.isRoot = lookup.path === "/";
    } catch (e) {
      ret.error = e.errno;
    }
    return ret;
  },
  createPath(parent, path, canRead, canWrite) {
    parent = typeof parent == "string" ? parent : FS.getPath(parent);
    var parts = path.split("/").reverse();
    while (parts.length) {
      var part = parts.pop();
      if (!part) continue;
      var current = PATH.join2(parent, part);
      try {
        FS.mkdir(current);
      } catch (e) {}
      parent = current;
    }
    return current;
  },
  createFile(parent, name, properties, canRead, canWrite) {
    var path = PATH.join2(typeof parent == "string" ? parent : FS.getPath(parent), name);
    var mode = FS_getMode(canRead, canWrite);
    return FS.create(path, mode);
  },
  createDataFile(parent, name, data, canRead, canWrite, canOwn) {
    var path = name;
    if (parent) {
      parent = typeof parent == "string" ? parent : FS.getPath(parent);
      path = name ? PATH.join2(parent, name) : parent;
    }
    var mode = FS_getMode(canRead, canWrite);
    var node = FS.create(path, mode);
    if (data) {
      if (typeof data == "string") {
        var arr = new Array(data.length);
        for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
        data = arr;
      }
      FS.chmod(node, mode | 146);
      var stream = FS.open(node, 577);
      FS.write(stream, data, 0, data.length, 0, canOwn);
      FS.close(stream);
      FS.chmod(node, mode);
    }
  },
  createDevice(parent, name, input, output) {
    var path = PATH.join2(typeof parent == "string" ? parent : FS.getPath(parent), name);
    var mode = FS_getMode(!!input, !!output);
    if (!FS.createDevice.major) FS.createDevice.major = 64;
    var dev = FS.makedev(FS.createDevice.major++, 0);
    FS.registerDevice(dev, {
      open(stream) {
        stream.seekable = false;
      },
      close(stream) {
        if (output?.buffer?.length) {
          output(10);
        }
      },
      read(stream, buffer, offset, length, pos) {
        /* ignored */ var bytesRead = 0;
        for (var i = 0; i < length; i++) {
          var result;
          try {
            result = input();
          } catch (e) {
            throw new FS.ErrnoError(29);
          }
          if (result === undefined && bytesRead === 0) {
            throw new FS.ErrnoError(6);
          }
          if (result === null || result === undefined) break;
          bytesRead++;
          buffer[offset + i] = result;
        }
        if (bytesRead) {
          stream.node.timestamp = Date.now();
        }
        return bytesRead;
      },
      write(stream, buffer, offset, length, pos) {
        for (var i = 0; i < length; i++) {
          try {
            output(buffer[offset + i]);
          } catch (e) {
            throw new FS.ErrnoError(29);
          }
        }
        if (length) {
          stream.node.timestamp = Date.now();
        }
        return i;
      }
    });
    return FS.mkdev(path, mode, dev);
  },
  forceLoadFile(obj) {
    if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
    if (typeof XMLHttpRequest != "undefined") {
      throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
    } else if (read_) {
      try {
        obj.contents = intArrayFromString(read_(obj.url), true);
        obj.usedBytes = obj.contents.length;
      } catch (e) {
        throw new FS.ErrnoError(29);
      }
    } else {
      throw new Error("Cannot load without read() or XMLHttpRequest.");
    }
  },
  createLazyFile(parent, name, url, canRead, canWrite) {
    class LazyUint8Array {
      constructor() {
        this.lengthKnown = false;
        this.chunks = [];
      }
      get(idx) {
        if (idx > this.length - 1 || idx < 0) {
          return undefined;
        }
        var chunkOffset = idx % this.chunkSize;
        var chunkNum = (idx / this.chunkSize) | 0;
        return this.getter(chunkNum)[chunkOffset];
      }
      setDataGetter(getter) {
        this.getter = getter;
      }
      cacheLength() {
        var xhr = new XMLHttpRequest;
        xhr.open("HEAD", url, false);
        xhr.send(null);
        if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
        var datalength = Number(xhr.getResponseHeader("Content-length"));
        var header;
        var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
        var usesGzip = (header = xhr.getResponseHeader("Content-Encoding")) && header === "gzip";
        var chunkSize = 1024 * 1024;
        if (!hasByteServing) chunkSize = datalength;
        var doXHR = (from, to) => {
          if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
          if (to > datalength - 1) throw new Error("only " + datalength + " bytes available! programmer error!");
          var xhr = new XMLHttpRequest;
          xhr.open("GET", url, false);
          if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
          xhr.responseType = "arraybuffer";
          if (xhr.overrideMimeType) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          }
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          if (xhr.response !== undefined) {
            return new Uint8Array(/** @type{Array<number>} */ (xhr.response || []));
          }
          return intArrayFromString(xhr.responseText || "", true);
        };
        var lazyArray = this;
        lazyArray.setDataGetter(chunkNum => {
          var start = chunkNum * chunkSize;
          var end = (chunkNum + 1) * chunkSize - 1;
          end = Math.min(end, datalength - 1);
          if (typeof lazyArray.chunks[chunkNum] == "undefined") {
            lazyArray.chunks[chunkNum] = doXHR(start, end);
          }
          if (typeof lazyArray.chunks[chunkNum] == "undefined") throw new Error("doXHR failed!");
          return lazyArray.chunks[chunkNum];
        });
        if (usesGzip || !datalength) {
          chunkSize = datalength = 1;
          datalength = this.getter(0).length;
          chunkSize = datalength;
          out("LazyFiles on gzip forces download of the whole file when length is accessed");
        }
        this._length = datalength;
        this._chunkSize = chunkSize;
        this.lengthKnown = true;
      }
      get length() {
        if (!this.lengthKnown) {
          this.cacheLength();
        }
        return this._length;
      }
      get chunkSize() {
        if (!this.lengthKnown) {
          this.cacheLength();
        }
        return this._chunkSize;
      }
    }
    if (typeof XMLHttpRequest != "undefined") {
      if (!ENVIRONMENT_IS_WORKER) throw "Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";
      var lazyArray = new LazyUint8Array;
      var properties = {
        isDevice: false,
        contents: lazyArray
      };
    } else {
      var properties = {
        isDevice: false,
        url: url
      };
    }
    var node = FS.createFile(parent, name, properties, canRead, canWrite);
    if (properties.contents) {
      node.contents = properties.contents;
    } else if (properties.url) {
      node.contents = null;
      node.url = properties.url;
    }
    Object.defineProperties(node, {
      usedBytes: {
        get: function() {
          return this.contents.length;
        }
      }
    });
    var stream_ops = {};
    var keys = Object.keys(node.stream_ops);
    keys.forEach(key => {
      var fn = node.stream_ops[key];
      stream_ops[key] = (...args) => {
        FS.forceLoadFile(node);
        return fn(...args);
      };
    });
    function writeChunks(stream, buffer, offset, length, position) {
      var contents = stream.node.contents;
      if (position >= contents.length) return 0;
      var size = Math.min(contents.length - position, length);
      if (contents.slice) {
        for (var i = 0; i < size; i++) {
          buffer[offset + i] = contents[position + i];
        }
      } else {
        for (var i = 0; i < size; i++) {
          buffer[offset + i] = contents.get(position + i);
        }
      }
      return size;
    }
    stream_ops.read = (stream, buffer, offset, length, position) => {
      FS.forceLoadFile(node);
      return writeChunks(stream, buffer, offset, length, position);
    };
    stream_ops.mmap = (stream, length, position, prot, flags) => {
      FS.forceLoadFile(node);
      var ptr = mmapAlloc(length);
      if (!ptr) {
        throw new FS.ErrnoError(48);
      }
      writeChunks(stream, HEAP8, ptr, length, position);
      return {
        ptr: ptr,
        allocated: true
      };
    };
    node.stream_ops = stream_ops;
    return node;
  }
};

var SYSCALLS = {
  DEFAULT_POLLMASK: 5,
  calculateAt(dirfd, path, allowEmpty) {
    if (PATH.isAbs(path)) {
      return path;
    }
    var dir;
    if (dirfd === -100) {
      dir = FS.cwd();
    } else {
      var dirstream = SYSCALLS.getStreamFromFD(dirfd);
      dir = dirstream.path;
    }
    if (path.length == 0) {
      if (!allowEmpty) {
        throw new FS.ErrnoError(44);
      }
      return dir;
    }
    return PATH.join2(dir, path);
  },
  doStat(func, path, buf) {
    var stat = func(path);
    HEAP32[((buf) >> 2)] = stat.dev;
    HEAP32[(((buf) + (4)) >> 2)] = stat.mode;
    HEAPU32[(((buf) + (8)) >> 2)] = stat.nlink;
    HEAP32[(((buf) + (12)) >> 2)] = stat.uid;
    HEAP32[(((buf) + (16)) >> 2)] = stat.gid;
    HEAP32[(((buf) + (20)) >> 2)] = stat.rdev;
    (tempI64 = [ stat.size >>> 0, (tempDouble = stat.size, (+(Math.abs(tempDouble))) >= 1 ? (tempDouble > 0 ? (+(Math.floor((tempDouble) / 4294967296))) >>> 0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble))) >>> 0)) / 4294967296))))) >>> 0) : 0) ], 
    HEAP32[(((buf) + (24)) >> 2)] = tempI64[0], HEAP32[(((buf) + (28)) >> 2)] = tempI64[1]);
    HEAP32[(((buf) + (32)) >> 2)] = 4096;
    HEAP32[(((buf) + (36)) >> 2)] = stat.blocks;
    var atime = stat.atime.getTime();
    var mtime = stat.mtime.getTime();
    var ctime = stat.ctime.getTime();
    (tempI64 = [ Math.floor(atime / 1e3) >>> 0, (tempDouble = Math.floor(atime / 1e3), 
    (+(Math.abs(tempDouble))) >= 1 ? (tempDouble > 0 ? (+(Math.floor((tempDouble) / 4294967296))) >>> 0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble))) >>> 0)) / 4294967296))))) >>> 0) : 0) ], 
    HEAP32[(((buf) + (40)) >> 2)] = tempI64[0], HEAP32[(((buf) + (44)) >> 2)] = tempI64[1]);
    HEAPU32[(((buf) + (48)) >> 2)] = (atime % 1e3) * 1e3;
    (tempI64 = [ Math.floor(mtime / 1e3) >>> 0, (tempDouble = Math.floor(mtime / 1e3), 
    (+(Math.abs(tempDouble))) >= 1 ? (tempDouble > 0 ? (+(Math.floor((tempDouble) / 4294967296))) >>> 0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble))) >>> 0)) / 4294967296))))) >>> 0) : 0) ], 
    HEAP32[(((buf) + (56)) >> 2)] = tempI64[0], HEAP32[(((buf) + (60)) >> 2)] = tempI64[1]);
    HEAPU32[(((buf) + (64)) >> 2)] = (mtime % 1e3) * 1e3;
    (tempI64 = [ Math.floor(ctime / 1e3) >>> 0, (tempDouble = Math.floor(ctime / 1e3), 
    (+(Math.abs(tempDouble))) >= 1 ? (tempDouble > 0 ? (+(Math.floor((tempDouble) / 4294967296))) >>> 0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble))) >>> 0)) / 4294967296))))) >>> 0) : 0) ], 
    HEAP32[(((buf) + (72)) >> 2)] = tempI64[0], HEAP32[(((buf) + (76)) >> 2)] = tempI64[1]);
    HEAPU32[(((buf) + (80)) >> 2)] = (ctime % 1e3) * 1e3;
    (tempI64 = [ stat.ino >>> 0, (tempDouble = stat.ino, (+(Math.abs(tempDouble))) >= 1 ? (tempDouble > 0 ? (+(Math.floor((tempDouble) / 4294967296))) >>> 0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble))) >>> 0)) / 4294967296))))) >>> 0) : 0) ], 
    HEAP32[(((buf) + (88)) >> 2)] = tempI64[0], HEAP32[(((buf) + (92)) >> 2)] = tempI64[1]);
    return 0;
  },
  doMsync(addr, stream, len, flags, offset) {
    if (!FS.isFile(stream.node.mode)) {
      throw new FS.ErrnoError(43);
    }
    if (flags & 2) {
      return 0;
    }
    var buffer = HEAPU8.slice(addr, addr + len);
    FS.msync(stream, buffer, offset, len, flags);
  },
  getStreamFromFD(fd) {
    var stream = FS.getStreamChecked(fd);
    return stream;
  },
  varargs: undefined,
  getStr(ptr) {
    var ret = UTF8ToString(ptr);
    return ret;
  }
};

function _fd_close(fd) {
  try {
    var stream = SYSCALLS.getStreamFromFD(fd);
    FS.close(stream);
    return 0;
  } catch (e) {
    if (typeof FS == "undefined" || !(e.name === "ErrnoError")) throw e;
    return e.errno;
  }
}

/** @param {number=} offset */ var doReadv = (stream, iov, iovcnt, offset) => {
  var ret = 0;
  for (var i = 0; i < iovcnt; i++) {
    var ptr = HEAPU32[((iov) >> 2)];
    var len = HEAPU32[(((iov) + (4)) >> 2)];
    iov += 8;
    var curr = FS.read(stream, HEAP8, ptr, len, offset);
    if (curr < 0) return -1;
    ret += curr;
    if (curr < len) break;
    if (typeof offset != "undefined") {
      offset += curr;
    }
  }
  return ret;
};

function _fd_read(fd, iov, iovcnt, pnum) {
  try {
    var stream = SYSCALLS.getStreamFromFD(fd);
    var num = doReadv(stream, iov, iovcnt);
    HEAPU32[((pnum) >> 2)] = num;
    return 0;
  } catch (e) {
    if (typeof FS == "undefined" || !(e.name === "ErrnoError")) throw e;
    return e.errno;
  }
}

var convertI32PairToI53Checked = (lo, hi) => ((hi + 2097152) >>> 0 < 4194305 - !!lo) ? (lo >>> 0) + hi * 4294967296 : NaN;

function _fd_seek(fd, offset_low, offset_high, whence, newOffset) {
  var offset = convertI32PairToI53Checked(offset_low, offset_high);
  try {
    if (isNaN(offset)) return 61;
    var stream = SYSCALLS.getStreamFromFD(fd);
    FS.llseek(stream, offset, whence);
    (tempI64 = [ stream.position >>> 0, (tempDouble = stream.position, (+(Math.abs(tempDouble))) >= 1 ? (tempDouble > 0 ? (+(Math.floor((tempDouble) / 4294967296))) >>> 0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble))) >>> 0)) / 4294967296))))) >>> 0) : 0) ], 
    HEAP32[((newOffset) >> 2)] = tempI64[0], HEAP32[(((newOffset) + (4)) >> 2)] = tempI64[1]);
    if (stream.getdents && offset === 0 && whence === 0) stream.getdents = null;
    return 0;
  } catch (e) {
    if (typeof FS == "undefined" || !(e.name === "ErrnoError")) throw e;
    return e.errno;
  }
}

/** @param {number=} offset */ var doWritev = (stream, iov, iovcnt, offset) => {
  var ret = 0;
  for (var i = 0; i < iovcnt; i++) {
    var ptr = HEAPU32[((iov) >> 2)];
    var len = HEAPU32[(((iov) + (4)) >> 2)];
    iov += 8;
    var curr = FS.write(stream, HEAP8, ptr, len, offset);
    if (curr < 0) return -1;
    ret += curr;
    if (typeof offset != "undefined") {
      offset += curr;
    }
  }
  return ret;
};

function _fd_write(fd, iov, iovcnt, pnum) {
  try {
    var stream = SYSCALLS.getStreamFromFD(fd);
    var num = doWritev(stream, iov, iovcnt);
    HEAPU32[((pnum) >> 2)] = num;
    return 0;
  } catch (e) {
    if (typeof FS == "undefined" || !(e.name === "ErrnoError")) throw e;
    return e.errno;
  }
}

var _getentropy = (buffer, size) => {
  randomFill(HEAPU8.subarray(buffer, buffer + size));
  return 0;
};

var _llvm_eh_typeid_for = type => type;

var isLeapYear = year => year % 4 === 0 && (year % 100 !== 0 || year % 400 === 0);

var arraySum = (array, index) => {
  var sum = 0;
  for (var i = 0; i <= index; sum += array[i++]) {}
  return sum;
};

var MONTH_DAYS_LEAP = [ 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ];

var MONTH_DAYS_REGULAR = [ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ];

var addDays = (date, days) => {
  var newDate = new Date(date.getTime());
  while (days > 0) {
    var leap = isLeapYear(newDate.getFullYear());
    var currentMonth = newDate.getMonth();
    var daysInCurrentMonth = (leap ? MONTH_DAYS_LEAP : MONTH_DAYS_REGULAR)[currentMonth];
    if (days > daysInCurrentMonth - newDate.getDate()) {
      days -= (daysInCurrentMonth - newDate.getDate() + 1);
      newDate.setDate(1);
      if (currentMonth < 11) {
        newDate.setMonth(currentMonth + 1);
      } else {
        newDate.setMonth(0);
        newDate.setFullYear(newDate.getFullYear() + 1);
      }
    } else {
      newDate.setDate(newDate.getDate() + days);
      return newDate;
    }
  }
  return newDate;
};

var writeArrayToMemory = (array, buffer) => {
  HEAP8.set(array, buffer);
};

var _strftime = (s, maxsize, format, tm) => {
  var tm_zone = HEAPU32[(((tm) + (40)) >> 2)];
  var date = {
    tm_sec: HEAP32[((tm) >> 2)],
    tm_min: HEAP32[(((tm) + (4)) >> 2)],
    tm_hour: HEAP32[(((tm) + (8)) >> 2)],
    tm_mday: HEAP32[(((tm) + (12)) >> 2)],
    tm_mon: HEAP32[(((tm) + (16)) >> 2)],
    tm_year: HEAP32[(((tm) + (20)) >> 2)],
    tm_wday: HEAP32[(((tm) + (24)) >> 2)],
    tm_yday: HEAP32[(((tm) + (28)) >> 2)],
    tm_isdst: HEAP32[(((tm) + (32)) >> 2)],
    tm_gmtoff: HEAP32[(((tm) + (36)) >> 2)],
    tm_zone: tm_zone ? UTF8ToString(tm_zone) : ""
  };
  var pattern = UTF8ToString(format);
  var EXPANSION_RULES_1 = {
    "%c": "%a %b %d %H:%M:%S %Y",
    "%D": "%m/%d/%y",
    "%F": "%Y-%m-%d",
    "%h": "%b",
    "%r": "%I:%M:%S %p",
    "%R": "%H:%M",
    "%T": "%H:%M:%S",
    "%x": "%m/%d/%y",
    "%X": "%H:%M:%S",
    "%Ec": "%c",
    "%EC": "%C",
    "%Ex": "%m/%d/%y",
    "%EX": "%H:%M:%S",
    "%Ey": "%y",
    "%EY": "%Y",
    "%Od": "%d",
    "%Oe": "%e",
    "%OH": "%H",
    "%OI": "%I",
    "%Om": "%m",
    "%OM": "%M",
    "%OS": "%S",
    "%Ou": "%u",
    "%OU": "%U",
    "%OV": "%V",
    "%Ow": "%w",
    "%OW": "%W",
    "%Oy": "%y"
  };
  for (var rule in EXPANSION_RULES_1) {
    pattern = pattern.replace(new RegExp(rule, "g"), EXPANSION_RULES_1[rule]);
  }
  var WEEKDAYS = [ "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" ];
  var MONTHS = [ "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" ];
  function leadingSomething(value, digits, character) {
    var str = typeof value == "number" ? value.toString() : (value || "");
    while (str.length < digits) {
      str = character[0] + str;
    }
    return str;
  }
  function leadingNulls(value, digits) {
    return leadingSomething(value, digits, "0");
  }
  function compareByDay(date1, date2) {
    function sgn(value) {
      return value < 0 ? -1 : (value > 0 ? 1 : 0);
    }
    var compare;
    if ((compare = sgn(date1.getFullYear() - date2.getFullYear())) === 0) {
      if ((compare = sgn(date1.getMonth() - date2.getMonth())) === 0) {
        compare = sgn(date1.getDate() - date2.getDate());
      }
    }
    return compare;
  }
  function getFirstWeekStartDate(janFourth) {
    switch (janFourth.getDay()) {
     case 0:
      return new Date(janFourth.getFullYear() - 1, 11, 29);

     case 1:
      return janFourth;

     case 2:
      return new Date(janFourth.getFullYear(), 0, 3);

     case 3:
      return new Date(janFourth.getFullYear(), 0, 2);

     case 4:
      return new Date(janFourth.getFullYear(), 0, 1);

     case 5:
      return new Date(janFourth.getFullYear() - 1, 11, 31);

     case 6:
      return new Date(janFourth.getFullYear() - 1, 11, 30);
    }
  }
  function getWeekBasedYear(date) {
    var thisDate = addDays(new Date(date.tm_year + 1900, 0, 1), date.tm_yday);
    var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
    var janFourthNextYear = new Date(thisDate.getFullYear() + 1, 0, 4);
    var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
    var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
    if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
      if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
        return thisDate.getFullYear() + 1;
      }
      return thisDate.getFullYear();
    }
    return thisDate.getFullYear() - 1;
  }
  var EXPANSION_RULES_2 = {
    "%a": date => WEEKDAYS[date.tm_wday].substring(0, 3),
    "%A": date => WEEKDAYS[date.tm_wday],
    "%b": date => MONTHS[date.tm_mon].substring(0, 3),
    "%B": date => MONTHS[date.tm_mon],
    "%C": date => {
      var year = date.tm_year + 1900;
      return leadingNulls((year / 100) | 0, 2);
    },
    "%d": date => leadingNulls(date.tm_mday, 2),
    "%e": date => leadingSomething(date.tm_mday, 2, " "),
    "%g": date => getWeekBasedYear(date).toString().substring(2),
    "%G": getWeekBasedYear,
    "%H": date => leadingNulls(date.tm_hour, 2),
    "%I": date => {
      var twelveHour = date.tm_hour;
      if (twelveHour == 0) twelveHour = 12; else if (twelveHour > 12) twelveHour -= 12;
      return leadingNulls(twelveHour, 2);
    },
    "%j": date => leadingNulls(date.tm_mday + arraySum(isLeapYear(date.tm_year + 1900) ? MONTH_DAYS_LEAP : MONTH_DAYS_REGULAR, date.tm_mon - 1), 3),
    "%m": date => leadingNulls(date.tm_mon + 1, 2),
    "%M": date => leadingNulls(date.tm_min, 2),
    "%n": () => "\n",
    "%p": date => {
      if (date.tm_hour >= 0 && date.tm_hour < 12) {
        return "AM";
      }
      return "PM";
    },
    "%S": date => leadingNulls(date.tm_sec, 2),
    "%t": () => "\t",
    "%u": date => date.tm_wday || 7,
    "%U": date => {
      var days = date.tm_yday + 7 - date.tm_wday;
      return leadingNulls(Math.floor(days / 7), 2);
    },
    "%V": date => {
      var val = Math.floor((date.tm_yday + 7 - (date.tm_wday + 6) % 7) / 7);
      if ((date.tm_wday + 371 - date.tm_yday - 2) % 7 <= 2) {
        val++;
      }
      if (!val) {
        val = 52;
        var dec31 = (date.tm_wday + 7 - date.tm_yday - 1) % 7;
        if (dec31 == 4 || (dec31 == 5 && isLeapYear(date.tm_year % 400 - 1))) {
          val++;
        }
      } else if (val == 53) {
        var jan1 = (date.tm_wday + 371 - date.tm_yday) % 7;
        if (jan1 != 4 && (jan1 != 3 || !isLeapYear(date.tm_year))) val = 1;
      }
      return leadingNulls(val, 2);
    },
    "%w": date => date.tm_wday,
    "%W": date => {
      var days = date.tm_yday + 7 - ((date.tm_wday + 6) % 7);
      return leadingNulls(Math.floor(days / 7), 2);
    },
    "%y": date => (date.tm_year + 1900).toString().substring(2),
    "%Y": date => date.tm_year + 1900,
    "%z": date => {
      var off = date.tm_gmtoff;
      var ahead = off >= 0;
      off = Math.abs(off) / 60;
      off = (off / 60) * 100 + (off % 60);
      return (ahead ? "+" : "-") + String("0000" + off).slice(-4);
    },
    "%Z": date => date.tm_zone,
    "%%": () => "%"
  };
  pattern = pattern.replace(/%%/g, "\0\0");
  for (var rule in EXPANSION_RULES_2) {
    if (pattern.includes(rule)) {
      pattern = pattern.replace(new RegExp(rule, "g"), EXPANSION_RULES_2[rule](date));
    }
  }
  pattern = pattern.replace(/\0\0/g, "%");
  var bytes = intArrayFromString(pattern, false);
  if (bytes.length > maxsize) {
    return 0;
  }
  writeArrayToMemory(bytes, s);
  return bytes.length - 1;
};

var _strftime_l = (s, maxsize, format, tm, loc) => _strftime(s, maxsize, format, tm);

/** @type {WebAssembly.Table} */ var wasmTable;

var getWasmTableEntry = funcPtr => wasmTable.get(funcPtr);

FS.createPreloadedFile = FS_createPreloadedFile;

FS.staticInit();

var wasmImports = {
  /** @export */ o: ___assert_fail,
  /** @export */ k: ___cxa_begin_catch,
  /** @export */ m: ___cxa_end_catch,
  /** @export */ ia: ___cxa_find_matching_catch_17,
  /** @export */ a: ___cxa_find_matching_catch_2,
  /** @export */ h: ___cxa_find_matching_catch_3,
  /** @export */ w: ___cxa_find_matching_catch_4,
  /** @export */ ha: ___cxa_find_matching_catch_6,
  /** @export */ Q: ___cxa_rethrow,
  /** @export */ v: ___cxa_throw,
  /** @export */ ta: ___cxa_uncaught_exceptions,
  /** @export */ e: ___resumeException,
  /** @export */ oa: __abort_js,
  /** @export */ ea: __emscripten_get_now_is_monotonic,
  /** @export */ la: _emscripten_date_now,
  /** @export */ Y: _emscripten_get_now,
  /** @export */ ua: _emscripten_resize_heap,
  /** @export */ qa: _environ_get,
  /** @export */ ra: _environ_sizes_get,
  /** @export */ S: _fd_close,
  /** @export */ sa: _fd_read,
  /** @export */ ca: _fd_seek,
  /** @export */ R: _fd_write,
  /** @export */ pa: _getentropy,
  /** @export */ A: invoke_di,
  /** @export */ ja: invoke_did,
  /** @export */ K: invoke_didi,
  /** @export */ E: invoke_dii,
  /** @export */ I: invoke_diii,
  /** @export */ J: invoke_diiii,
  /** @export */ N: invoke_fi,
  /** @export */ na: invoke_fii,
  /** @export */ s: invoke_i,
  /** @export */ d: invoke_ii,
  /** @export */ fa: invoke_iid,
  /** @export */ ka: invoke_iifi,
  /** @export */ b: invoke_iii,
  /** @export */ L: invoke_iiifii,
  /** @export */ g: invoke_iiii,
  /** @export */ ga: invoke_iiiidd,
  /** @export */ n: invoke_iiiii,
  /** @export */ da: invoke_iiiiid,
  /** @export */ x: invoke_iiiiii,
  /** @export */ t: invoke_iiiiiii,
  /** @export */ G: invoke_iiiiiiii,
  /** @export */ P: invoke_iiiiiiiii,
  /** @export */ D: invoke_iiiiiiiiiiii,
  /** @export */ T: invoke_iij,
  /** @export */ ba: invoke_iiji,
  /** @export */ W: invoke_ijiij,
  /** @export */ U: invoke_j,
  /** @export */ Z: invoke_jiiii,
  /** @export */ j: invoke_v,
  /** @export */ l: invoke_vi,
  /** @export */ B: invoke_vid,
  /** @export */ c: invoke_vii,
  /** @export */ F: invoke_viid,
  /** @export */ M: invoke_viif,
  /** @export */ f: invoke_viii,
  /** @export */ ma: invoke_viiidi,
  /** @export */ i: invoke_viiii,
  /** @export */ p: invoke_viiiii,
  /** @export */ y: invoke_viiiiii,
  /** @export */ r: invoke_viiiiiii,
  /** @export */ H: invoke_viiiiiiii,
  /** @export */ O: invoke_viiiiiiiii,
  /** @export */ z: invoke_viiiiiiiiii,
  /** @export */ C: invoke_viiiiiiiiiiiiiii,
  /** @export */ $: invoke_viiij,
  /** @export */ _: invoke_viij,
  /** @export */ X: invoke_viiji,
  /** @export */ aa: invoke_vij,
  /** @export */ V: invoke_viji,
  /** @export */ q: _llvm_eh_typeid_for,
  /** @export */ u: _strftime_l
};

var wasmExports = createWasm();

var ___wasm_call_ctors = () => (___wasm_call_ctors = wasmExports["wa"])();

var _openmpt_get_library_version = Module["_openmpt_get_library_version"] = () => (_openmpt_get_library_version = Module["_openmpt_get_library_version"] = wasmExports["xa"])();

var __ZN7openmpt19get_library_versionEv = Module["__ZN7openmpt19get_library_versionEv"] = () => (__ZN7openmpt19get_library_versionEv = Module["__ZN7openmpt19get_library_versionEv"] = wasmExports["ya"])();

var _openmpt_get_core_version = Module["_openmpt_get_core_version"] = () => (_openmpt_get_core_version = Module["_openmpt_get_core_version"] = wasmExports["za"])();

var __ZN7openmpt16get_core_versionEv = Module["__ZN7openmpt16get_core_versionEv"] = () => (__ZN7openmpt16get_core_versionEv = Module["__ZN7openmpt16get_core_versionEv"] = wasmExports["Aa"])();

var _openmpt_free_string = Module["_openmpt_free_string"] = a0 => (_openmpt_free_string = Module["_openmpt_free_string"] = wasmExports["Ba"])(a0);

var _free = Module["_free"] = a0 => (_free = Module["_free"] = wasmExports["Ca"])(a0);

var _openmpt_get_string = Module["_openmpt_get_string"] = a0 => (_openmpt_get_string = Module["_openmpt_get_string"] = wasmExports["Da"])(a0);

var __ZN7openmpt6string3getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt6string3getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = (a0, a1) => (__ZN7openmpt6string3getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt6string3getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = wasmExports["Ea"])(a0, a1);

var _openmpt_get_supported_extensions = Module["_openmpt_get_supported_extensions"] = () => (_openmpt_get_supported_extensions = Module["_openmpt_get_supported_extensions"] = wasmExports["Fa"])();

var _openmpt_is_extension_supported = Module["_openmpt_is_extension_supported"] = a0 => (_openmpt_is_extension_supported = Module["_openmpt_is_extension_supported"] = wasmExports["Ga"])(a0);

var _openmpt_log_func_default = Module["_openmpt_log_func_default"] = (a0, a1) => (_openmpt_log_func_default = Module["_openmpt_log_func_default"] = wasmExports["Ha"])(a0, a1);

var _openmpt_log_func_silent = Module["_openmpt_log_func_silent"] = (a0, a1) => (_openmpt_log_func_silent = Module["_openmpt_log_func_silent"] = wasmExports["Ia"])(a0, a1);

var _openmpt_error_is_transient = Module["_openmpt_error_is_transient"] = a0 => (_openmpt_error_is_transient = Module["_openmpt_error_is_transient"] = wasmExports["Ja"])(a0);

var _openmpt_error_string = Module["_openmpt_error_string"] = a0 => (_openmpt_error_string = Module["_openmpt_error_string"] = wasmExports["Ka"])(a0);

var _openmpt_error_func_default = Module["_openmpt_error_func_default"] = (a0, a1) => (_openmpt_error_func_default = Module["_openmpt_error_func_default"] = wasmExports["La"])(a0, a1);

var _openmpt_error_func_log = Module["_openmpt_error_func_log"] = (a0, a1) => (_openmpt_error_func_log = Module["_openmpt_error_func_log"] = wasmExports["Ma"])(a0, a1);

var _openmpt_error_func_store = Module["_openmpt_error_func_store"] = (a0, a1) => (_openmpt_error_func_store = Module["_openmpt_error_func_store"] = wasmExports["Na"])(a0, a1);

var _openmpt_error_func_ignore = Module["_openmpt_error_func_ignore"] = (a0, a1) => (_openmpt_error_func_ignore = Module["_openmpt_error_func_ignore"] = wasmExports["Oa"])(a0, a1);

var _openmpt_error_func_errno = Module["_openmpt_error_func_errno"] = (a0, a1) => (_openmpt_error_func_errno = Module["_openmpt_error_func_errno"] = wasmExports["Pa"])(a0, a1);

var _openmpt_error_func_errno_userdata = Module["_openmpt_error_func_errno_userdata"] = a0 => (_openmpt_error_func_errno_userdata = Module["_openmpt_error_func_errno_userdata"] = wasmExports["Qa"])(a0);

var _openmpt_could_open_probability = Module["_openmpt_could_open_probability"] = (a0, a1, a2, a3, a4) => (_openmpt_could_open_probability = Module["_openmpt_could_open_probability"] = wasmExports["Ra"])(a0, a1, a2, a3, a4);

var _openmpt_could_open_probability2 = Module["_openmpt_could_open_probability2"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8) => (_openmpt_could_open_probability2 = Module["_openmpt_could_open_probability2"] = wasmExports["Sa"])(a0, a1, a2, a3, a4, a5, a6, a7, a8);

var _openmpt_could_open_propability = Module["_openmpt_could_open_propability"] = (a0, a1, a2, a3, a4) => (_openmpt_could_open_propability = Module["_openmpt_could_open_propability"] = wasmExports["Ta"])(a0, a1, a2, a3, a4);

var _openmpt_probe_file_header_get_recommended_size = Module["_openmpt_probe_file_header_get_recommended_size"] = () => (_openmpt_probe_file_header_get_recommended_size = Module["_openmpt_probe_file_header_get_recommended_size"] = wasmExports["Ua"])();

var _openmpt_probe_file_header = Module["_openmpt_probe_file_header"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11) => (_openmpt_probe_file_header = Module["_openmpt_probe_file_header"] = wasmExports["Va"])(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11);

var _openmpt_probe_file_header_without_filesize = Module["_openmpt_probe_file_header_without_filesize"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8, a9) => (_openmpt_probe_file_header_without_filesize = Module["_openmpt_probe_file_header_without_filesize"] = wasmExports["Wa"])(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);

var _openmpt_probe_file_header_from_stream = Module["_openmpt_probe_file_header_from_stream"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8, a9) => (_openmpt_probe_file_header_from_stream = Module["_openmpt_probe_file_header_from_stream"] = wasmExports["Xa"])(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);

var _openmpt_module_create = Module["_openmpt_module_create"] = (a0, a1, a2, a3, a4) => (_openmpt_module_create = Module["_openmpt_module_create"] = wasmExports["Ya"])(a0, a1, a2, a3, a4);

var _openmpt_module_create2 = Module["_openmpt_module_create2"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8) => (_openmpt_module_create2 = Module["_openmpt_module_create2"] = wasmExports["Za"])(a0, a1, a2, a3, a4, a5, a6, a7, a8);

var _openmpt_module_create_from_memory = Module["_openmpt_module_create_from_memory"] = (a0, a1, a2, a3, a4) => (_openmpt_module_create_from_memory = Module["_openmpt_module_create_from_memory"] = wasmExports["_a"])(a0, a1, a2, a3, a4);

var _openmpt_module_create_from_memory2 = Module["_openmpt_module_create_from_memory2"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8) => (_openmpt_module_create_from_memory2 = Module["_openmpt_module_create_from_memory2"] = wasmExports["$a"])(a0, a1, a2, a3, a4, a5, a6, a7, a8);

var _openmpt_module_destroy = Module["_openmpt_module_destroy"] = a0 => (_openmpt_module_destroy = Module["_openmpt_module_destroy"] = wasmExports["ab"])(a0);

var _openmpt_module_set_log_func = Module["_openmpt_module_set_log_func"] = (a0, a1, a2) => (_openmpt_module_set_log_func = Module["_openmpt_module_set_log_func"] = wasmExports["bb"])(a0, a1, a2);

var _openmpt_module_set_error_func = Module["_openmpt_module_set_error_func"] = (a0, a1, a2) => (_openmpt_module_set_error_func = Module["_openmpt_module_set_error_func"] = wasmExports["cb"])(a0, a1, a2);

var _openmpt_module_error_get_last = Module["_openmpt_module_error_get_last"] = a0 => (_openmpt_module_error_get_last = Module["_openmpt_module_error_get_last"] = wasmExports["db"])(a0);

var _openmpt_module_error_get_last_message = Module["_openmpt_module_error_get_last_message"] = a0 => (_openmpt_module_error_get_last_message = Module["_openmpt_module_error_get_last_message"] = wasmExports["eb"])(a0);

var _openmpt_module_error_set_last = Module["_openmpt_module_error_set_last"] = (a0, a1) => (_openmpt_module_error_set_last = Module["_openmpt_module_error_set_last"] = wasmExports["fb"])(a0, a1);

var _openmpt_module_error_clear = Module["_openmpt_module_error_clear"] = a0 => (_openmpt_module_error_clear = Module["_openmpt_module_error_clear"] = wasmExports["gb"])(a0);

var _openmpt_module_select_subsong = Module["_openmpt_module_select_subsong"] = (a0, a1) => (_openmpt_module_select_subsong = Module["_openmpt_module_select_subsong"] = wasmExports["hb"])(a0, a1);

var _openmpt_module_get_selected_subsong = Module["_openmpt_module_get_selected_subsong"] = a0 => (_openmpt_module_get_selected_subsong = Module["_openmpt_module_get_selected_subsong"] = wasmExports["ib"])(a0);

var _openmpt_module_set_repeat_count = Module["_openmpt_module_set_repeat_count"] = (a0, a1) => (_openmpt_module_set_repeat_count = Module["_openmpt_module_set_repeat_count"] = wasmExports["jb"])(a0, a1);

var _openmpt_module_get_repeat_count = Module["_openmpt_module_get_repeat_count"] = a0 => (_openmpt_module_get_repeat_count = Module["_openmpt_module_get_repeat_count"] = wasmExports["kb"])(a0);

var _openmpt_module_get_duration_seconds = Module["_openmpt_module_get_duration_seconds"] = a0 => (_openmpt_module_get_duration_seconds = Module["_openmpt_module_get_duration_seconds"] = wasmExports["lb"])(a0);

var _openmpt_module_set_position_seconds = Module["_openmpt_module_set_position_seconds"] = (a0, a1) => (_openmpt_module_set_position_seconds = Module["_openmpt_module_set_position_seconds"] = wasmExports["mb"])(a0, a1);

var _openmpt_module_get_position_seconds = Module["_openmpt_module_get_position_seconds"] = a0 => (_openmpt_module_get_position_seconds = Module["_openmpt_module_get_position_seconds"] = wasmExports["nb"])(a0);

var _openmpt_module_set_position_order_row = Module["_openmpt_module_set_position_order_row"] = (a0, a1, a2) => (_openmpt_module_set_position_order_row = Module["_openmpt_module_set_position_order_row"] = wasmExports["ob"])(a0, a1, a2);

var _openmpt_module_get_render_param = Module["_openmpt_module_get_render_param"] = (a0, a1, a2) => (_openmpt_module_get_render_param = Module["_openmpt_module_get_render_param"] = wasmExports["pb"])(a0, a1, a2);

var _openmpt_module_set_render_param = Module["_openmpt_module_set_render_param"] = (a0, a1, a2) => (_openmpt_module_set_render_param = Module["_openmpt_module_set_render_param"] = wasmExports["qb"])(a0, a1, a2);

var _openmpt_module_read_mono = Module["_openmpt_module_read_mono"] = (a0, a1, a2, a3) => (_openmpt_module_read_mono = Module["_openmpt_module_read_mono"] = wasmExports["rb"])(a0, a1, a2, a3);

var _openmpt_module_read_stereo = Module["_openmpt_module_read_stereo"] = (a0, a1, a2, a3, a4) => (_openmpt_module_read_stereo = Module["_openmpt_module_read_stereo"] = wasmExports["sb"])(a0, a1, a2, a3, a4);

var _openmpt_module_read_quad = Module["_openmpt_module_read_quad"] = (a0, a1, a2, a3, a4, a5, a6) => (_openmpt_module_read_quad = Module["_openmpt_module_read_quad"] = wasmExports["tb"])(a0, a1, a2, a3, a4, a5, a6);

var _openmpt_module_read_float_mono = Module["_openmpt_module_read_float_mono"] = (a0, a1, a2, a3) => (_openmpt_module_read_float_mono = Module["_openmpt_module_read_float_mono"] = wasmExports["ub"])(a0, a1, a2, a3);

var _openmpt_module_read_float_stereo = Module["_openmpt_module_read_float_stereo"] = (a0, a1, a2, a3, a4) => (_openmpt_module_read_float_stereo = Module["_openmpt_module_read_float_stereo"] = wasmExports["vb"])(a0, a1, a2, a3, a4);

var _openmpt_module_read_float_quad = Module["_openmpt_module_read_float_quad"] = (a0, a1, a2, a3, a4, a5, a6) => (_openmpt_module_read_float_quad = Module["_openmpt_module_read_float_quad"] = wasmExports["wb"])(a0, a1, a2, a3, a4, a5, a6);

var _openmpt_module_read_interleaved_stereo = Module["_openmpt_module_read_interleaved_stereo"] = (a0, a1, a2, a3) => (_openmpt_module_read_interleaved_stereo = Module["_openmpt_module_read_interleaved_stereo"] = wasmExports["xb"])(a0, a1, a2, a3);

var _openmpt_module_read_interleaved_quad = Module["_openmpt_module_read_interleaved_quad"] = (a0, a1, a2, a3) => (_openmpt_module_read_interleaved_quad = Module["_openmpt_module_read_interleaved_quad"] = wasmExports["yb"])(a0, a1, a2, a3);

var _openmpt_module_read_interleaved_float_stereo = Module["_openmpt_module_read_interleaved_float_stereo"] = (a0, a1, a2, a3) => (_openmpt_module_read_interleaved_float_stereo = Module["_openmpt_module_read_interleaved_float_stereo"] = wasmExports["zb"])(a0, a1, a2, a3);

var _openmpt_module_read_interleaved_float_quad = Module["_openmpt_module_read_interleaved_float_quad"] = (a0, a1, a2, a3) => (_openmpt_module_read_interleaved_float_quad = Module["_openmpt_module_read_interleaved_float_quad"] = wasmExports["Ab"])(a0, a1, a2, a3);

var _openmpt_module_get_metadata_keys = Module["_openmpt_module_get_metadata_keys"] = a0 => (_openmpt_module_get_metadata_keys = Module["_openmpt_module_get_metadata_keys"] = wasmExports["Bb"])(a0);

var _openmpt_module_get_metadata = Module["_openmpt_module_get_metadata"] = (a0, a1) => (_openmpt_module_get_metadata = Module["_openmpt_module_get_metadata"] = wasmExports["Cb"])(a0, a1);

var _openmpt_module_get_current_estimated_bpm = Module["_openmpt_module_get_current_estimated_bpm"] = a0 => (_openmpt_module_get_current_estimated_bpm = Module["_openmpt_module_get_current_estimated_bpm"] = wasmExports["Db"])(a0);

var _openmpt_module_get_current_speed = Module["_openmpt_module_get_current_speed"] = a0 => (_openmpt_module_get_current_speed = Module["_openmpt_module_get_current_speed"] = wasmExports["Eb"])(a0);

var _openmpt_module_get_current_tempo = Module["_openmpt_module_get_current_tempo"] = a0 => (_openmpt_module_get_current_tempo = Module["_openmpt_module_get_current_tempo"] = wasmExports["Fb"])(a0);

var _openmpt_module_get_current_tempo2 = Module["_openmpt_module_get_current_tempo2"] = a0 => (_openmpt_module_get_current_tempo2 = Module["_openmpt_module_get_current_tempo2"] = wasmExports["Gb"])(a0);

var _openmpt_module_get_current_order = Module["_openmpt_module_get_current_order"] = a0 => (_openmpt_module_get_current_order = Module["_openmpt_module_get_current_order"] = wasmExports["Hb"])(a0);

var _openmpt_module_get_current_pattern = Module["_openmpt_module_get_current_pattern"] = a0 => (_openmpt_module_get_current_pattern = Module["_openmpt_module_get_current_pattern"] = wasmExports["Ib"])(a0);

var _openmpt_module_get_current_row = Module["_openmpt_module_get_current_row"] = a0 => (_openmpt_module_get_current_row = Module["_openmpt_module_get_current_row"] = wasmExports["Jb"])(a0);

var _openmpt_module_get_current_playing_channels = Module["_openmpt_module_get_current_playing_channels"] = a0 => (_openmpt_module_get_current_playing_channels = Module["_openmpt_module_get_current_playing_channels"] = wasmExports["Kb"])(a0);

var _openmpt_module_get_current_channel_vu_mono = Module["_openmpt_module_get_current_channel_vu_mono"] = (a0, a1) => (_openmpt_module_get_current_channel_vu_mono = Module["_openmpt_module_get_current_channel_vu_mono"] = wasmExports["Lb"])(a0, a1);

var _openmpt_module_get_current_channel_vu_left = Module["_openmpt_module_get_current_channel_vu_left"] = (a0, a1) => (_openmpt_module_get_current_channel_vu_left = Module["_openmpt_module_get_current_channel_vu_left"] = wasmExports["Mb"])(a0, a1);

var _openmpt_module_get_current_channel_vu_right = Module["_openmpt_module_get_current_channel_vu_right"] = (a0, a1) => (_openmpt_module_get_current_channel_vu_right = Module["_openmpt_module_get_current_channel_vu_right"] = wasmExports["Nb"])(a0, a1);

var _openmpt_module_get_current_channel_vu_rear_left = Module["_openmpt_module_get_current_channel_vu_rear_left"] = (a0, a1) => (_openmpt_module_get_current_channel_vu_rear_left = Module["_openmpt_module_get_current_channel_vu_rear_left"] = wasmExports["Ob"])(a0, a1);

var _openmpt_module_get_current_channel_vu_rear_right = Module["_openmpt_module_get_current_channel_vu_rear_right"] = (a0, a1) => (_openmpt_module_get_current_channel_vu_rear_right = Module["_openmpt_module_get_current_channel_vu_rear_right"] = wasmExports["Pb"])(a0, a1);

var _openmpt_module_get_num_subsongs = Module["_openmpt_module_get_num_subsongs"] = a0 => (_openmpt_module_get_num_subsongs = Module["_openmpt_module_get_num_subsongs"] = wasmExports["Qb"])(a0);

var _openmpt_module_get_num_channels = Module["_openmpt_module_get_num_channels"] = a0 => (_openmpt_module_get_num_channels = Module["_openmpt_module_get_num_channels"] = wasmExports["Rb"])(a0);

var _openmpt_module_get_num_orders = Module["_openmpt_module_get_num_orders"] = a0 => (_openmpt_module_get_num_orders = Module["_openmpt_module_get_num_orders"] = wasmExports["Sb"])(a0);

var _openmpt_module_get_num_patterns = Module["_openmpt_module_get_num_patterns"] = a0 => (_openmpt_module_get_num_patterns = Module["_openmpt_module_get_num_patterns"] = wasmExports["Tb"])(a0);

var _openmpt_module_get_num_instruments = Module["_openmpt_module_get_num_instruments"] = a0 => (_openmpt_module_get_num_instruments = Module["_openmpt_module_get_num_instruments"] = wasmExports["Ub"])(a0);

var _openmpt_module_get_num_samples = Module["_openmpt_module_get_num_samples"] = a0 => (_openmpt_module_get_num_samples = Module["_openmpt_module_get_num_samples"] = wasmExports["Vb"])(a0);

var _openmpt_module_get_subsong_name = Module["_openmpt_module_get_subsong_name"] = (a0, a1) => (_openmpt_module_get_subsong_name = Module["_openmpt_module_get_subsong_name"] = wasmExports["Wb"])(a0, a1);

var _openmpt_module_get_channel_name = Module["_openmpt_module_get_channel_name"] = (a0, a1) => (_openmpt_module_get_channel_name = Module["_openmpt_module_get_channel_name"] = wasmExports["Xb"])(a0, a1);

var _openmpt_module_get_order_name = Module["_openmpt_module_get_order_name"] = (a0, a1) => (_openmpt_module_get_order_name = Module["_openmpt_module_get_order_name"] = wasmExports["Yb"])(a0, a1);

var _openmpt_module_get_pattern_name = Module["_openmpt_module_get_pattern_name"] = (a0, a1) => (_openmpt_module_get_pattern_name = Module["_openmpt_module_get_pattern_name"] = wasmExports["Zb"])(a0, a1);

var _openmpt_module_get_instrument_name = Module["_openmpt_module_get_instrument_name"] = (a0, a1) => (_openmpt_module_get_instrument_name = Module["_openmpt_module_get_instrument_name"] = wasmExports["_b"])(a0, a1);

var _openmpt_module_get_sample_name = Module["_openmpt_module_get_sample_name"] = (a0, a1) => (_openmpt_module_get_sample_name = Module["_openmpt_module_get_sample_name"] = wasmExports["$b"])(a0, a1);

var _openmpt_module_get_order_pattern = Module["_openmpt_module_get_order_pattern"] = (a0, a1) => (_openmpt_module_get_order_pattern = Module["_openmpt_module_get_order_pattern"] = wasmExports["ac"])(a0, a1);

var _openmpt_module_get_pattern_num_rows = Module["_openmpt_module_get_pattern_num_rows"] = (a0, a1) => (_openmpt_module_get_pattern_num_rows = Module["_openmpt_module_get_pattern_num_rows"] = wasmExports["bc"])(a0, a1);

var _openmpt_module_get_pattern_row_channel_command = Module["_openmpt_module_get_pattern_row_channel_command"] = (a0, a1, a2, a3, a4) => (_openmpt_module_get_pattern_row_channel_command = Module["_openmpt_module_get_pattern_row_channel_command"] = wasmExports["cc"])(a0, a1, a2, a3, a4);

var _openmpt_module_format_pattern_row_channel_command = Module["_openmpt_module_format_pattern_row_channel_command"] = (a0, a1, a2, a3, a4) => (_openmpt_module_format_pattern_row_channel_command = Module["_openmpt_module_format_pattern_row_channel_command"] = wasmExports["dc"])(a0, a1, a2, a3, a4);

var _openmpt_module_highlight_pattern_row_channel_command = Module["_openmpt_module_highlight_pattern_row_channel_command"] = (a0, a1, a2, a3, a4) => (_openmpt_module_highlight_pattern_row_channel_command = Module["_openmpt_module_highlight_pattern_row_channel_command"] = wasmExports["ec"])(a0, a1, a2, a3, a4);

var _openmpt_module_format_pattern_row_channel = Module["_openmpt_module_format_pattern_row_channel"] = (a0, a1, a2, a3, a4, a5) => (_openmpt_module_format_pattern_row_channel = Module["_openmpt_module_format_pattern_row_channel"] = wasmExports["fc"])(a0, a1, a2, a3, a4, a5);

var _openmpt_module_highlight_pattern_row_channel = Module["_openmpt_module_highlight_pattern_row_channel"] = (a0, a1, a2, a3, a4, a5) => (_openmpt_module_highlight_pattern_row_channel = Module["_openmpt_module_highlight_pattern_row_channel"] = wasmExports["gc"])(a0, a1, a2, a3, a4, a5);

var _openmpt_module_get_ctls = Module["_openmpt_module_get_ctls"] = a0 => (_openmpt_module_get_ctls = Module["_openmpt_module_get_ctls"] = wasmExports["hc"])(a0);

var _openmpt_module_ctl_get = Module["_openmpt_module_ctl_get"] = (a0, a1) => (_openmpt_module_ctl_get = Module["_openmpt_module_ctl_get"] = wasmExports["ic"])(a0, a1);

var _openmpt_module_ctl_get_boolean = Module["_openmpt_module_ctl_get_boolean"] = (a0, a1) => (_openmpt_module_ctl_get_boolean = Module["_openmpt_module_ctl_get_boolean"] = wasmExports["jc"])(a0, a1);

var _openmpt_module_ctl_get_integer = Module["_openmpt_module_ctl_get_integer"] = (a0, a1) => (_openmpt_module_ctl_get_integer = Module["_openmpt_module_ctl_get_integer"] = wasmExports["kc"])(a0, a1);

var _openmpt_module_ctl_get_floatingpoint = Module["_openmpt_module_ctl_get_floatingpoint"] = (a0, a1) => (_openmpt_module_ctl_get_floatingpoint = Module["_openmpt_module_ctl_get_floatingpoint"] = wasmExports["lc"])(a0, a1);

var _openmpt_module_ctl_get_text = Module["_openmpt_module_ctl_get_text"] = (a0, a1) => (_openmpt_module_ctl_get_text = Module["_openmpt_module_ctl_get_text"] = wasmExports["mc"])(a0, a1);

var _openmpt_module_ctl_set = Module["_openmpt_module_ctl_set"] = (a0, a1, a2) => (_openmpt_module_ctl_set = Module["_openmpt_module_ctl_set"] = wasmExports["nc"])(a0, a1, a2);

var _openmpt_module_ctl_set_boolean = Module["_openmpt_module_ctl_set_boolean"] = (a0, a1, a2) => (_openmpt_module_ctl_set_boolean = Module["_openmpt_module_ctl_set_boolean"] = wasmExports["oc"])(a0, a1, a2);

var _openmpt_module_ctl_set_integer = Module["_openmpt_module_ctl_set_integer"] = (a0, a1, a2, a3) => (_openmpt_module_ctl_set_integer = Module["_openmpt_module_ctl_set_integer"] = wasmExports["pc"])(a0, a1, a2, a3);

var _openmpt_module_ctl_set_floatingpoint = Module["_openmpt_module_ctl_set_floatingpoint"] = (a0, a1, a2) => (_openmpt_module_ctl_set_floatingpoint = Module["_openmpt_module_ctl_set_floatingpoint"] = wasmExports["qc"])(a0, a1, a2);

var _openmpt_module_ctl_set_text = Module["_openmpt_module_ctl_set_text"] = (a0, a1, a2) => (_openmpt_module_ctl_set_text = Module["_openmpt_module_ctl_set_text"] = wasmExports["rc"])(a0, a1, a2);

var _openmpt_module_ext_create = Module["_openmpt_module_ext_create"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8) => (_openmpt_module_ext_create = Module["_openmpt_module_ext_create"] = wasmExports["sc"])(a0, a1, a2, a3, a4, a5, a6, a7, a8);

var _openmpt_module_ext_create_from_memory = Module["_openmpt_module_ext_create_from_memory"] = (a0, a1, a2, a3, a4, a5, a6, a7, a8) => (_openmpt_module_ext_create_from_memory = Module["_openmpt_module_ext_create_from_memory"] = wasmExports["tc"])(a0, a1, a2, a3, a4, a5, a6, a7, a8);

var _openmpt_module_ext_destroy = Module["_openmpt_module_ext_destroy"] = a0 => (_openmpt_module_ext_destroy = Module["_openmpt_module_ext_destroy"] = wasmExports["uc"])(a0);

var _openmpt_module_ext_get_module = Module["_openmpt_module_ext_get_module"] = a0 => (_openmpt_module_ext_get_module = Module["_openmpt_module_ext_get_module"] = wasmExports["vc"])(a0);

var _openmpt_module_ext_get_interface = Module["_openmpt_module_ext_get_interface"] = (a0, a1, a2, a3) => (_openmpt_module_ext_get_interface = Module["_openmpt_module_ext_get_interface"] = wasmExports["wc"])(a0, a1, a2, a3);

var __ZN7openmpt9exceptionC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt9exceptionC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = (a0, a1) => (__ZN7openmpt9exceptionC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt9exceptionC2ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = wasmExports["xc"])(a0, a1);

var __ZNK7openmpt9exception4whatEv = Module["__ZNK7openmpt9exception4whatEv"] = a0 => (__ZNK7openmpt9exception4whatEv = Module["__ZNK7openmpt9exception4whatEv"] = wasmExports["yc"])(a0);

var __ZN7openmpt9exceptionD2Ev = Module["__ZN7openmpt9exceptionD2Ev"] = a0 => (__ZN7openmpt9exceptionD2Ev = Module["__ZN7openmpt9exceptionD2Ev"] = wasmExports["zc"])(a0);

var _malloc = Module["_malloc"] = a0 => (_malloc = Module["_malloc"] = wasmExports["Ac"])(a0);

var __ZN7openmpt9exceptionC2ERKS0_ = Module["__ZN7openmpt9exceptionC2ERKS0_"] = (a0, a1) => (__ZN7openmpt9exceptionC2ERKS0_ = Module["__ZN7openmpt9exceptionC2ERKS0_"] = wasmExports["Bc"])(a0, a1);

var __ZN7openmpt9exceptionC2EOS0_ = Module["__ZN7openmpt9exceptionC2EOS0_"] = (a0, a1) => (__ZN7openmpt9exceptionC2EOS0_ = Module["__ZN7openmpt9exceptionC2EOS0_"] = wasmExports["Cc"])(a0, a1);

var __ZN7openmpt9exceptionaSERKS0_ = Module["__ZN7openmpt9exceptionaSERKS0_"] = (a0, a1) => (__ZN7openmpt9exceptionaSERKS0_ = Module["__ZN7openmpt9exceptionaSERKS0_"] = wasmExports["Dc"])(a0, a1);

var __ZN7openmpt9exceptionaSEOS0_ = Module["__ZN7openmpt9exceptionaSEOS0_"] = (a0, a1) => (__ZN7openmpt9exceptionaSEOS0_ = Module["__ZN7openmpt9exceptionaSEOS0_"] = wasmExports["Ec"])(a0, a1);

var __ZN7openmpt9exceptionD0Ev = Module["__ZN7openmpt9exceptionD0Ev"] = a0 => (__ZN7openmpt9exceptionD0Ev = Module["__ZN7openmpt9exceptionD0Ev"] = wasmExports["Fc"])(a0);

var __ZN7openmpt24get_supported_extensionsEv = Module["__ZN7openmpt24get_supported_extensionsEv"] = a0 => (__ZN7openmpt24get_supported_extensionsEv = Module["__ZN7openmpt24get_supported_extensionsEv"] = wasmExports["Gc"])(a0);

var __ZN7openmpt22is_extension_supportedERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZN7openmpt22is_extension_supportedERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = a0 => (__ZN7openmpt22is_extension_supportedERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE = Module["__ZN7openmpt22is_extension_supportedERKNSt3__212basic_stringIcNS0_11char_traitsIcEENS0_9allocatorIcEEEE"] = wasmExports["Hc"])(a0);

var __ZN7openmpt23is_extension_supported2ENSt3__217basic_string_viewIcNS0_11char_traitsIcEEEE = Module["__ZN7openmpt23is_extension_supported2ENSt3__217basic_string_viewIcNS0_11char_traitsIcEEEE"] = a0 => (__ZN7openmpt23is_extension_supported2ENSt3__217basic_string_viewIcNS0_11char_traitsIcEEEE = Module["__ZN7openmpt23is_extension_supported2ENSt3__217basic_string_viewIcNS0_11char_traitsIcEEEE"] = wasmExports["Ic"])(a0);

var __ZN7openmpt22could_open_probabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE = Module["__ZN7openmpt22could_open_probabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE"] = (a0, a1, a2) => (__ZN7openmpt22could_open_probabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE = Module["__ZN7openmpt22could_open_probabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE"] = wasmExports["Jc"])(a0, a1, a2);

var __ZN7openmpt22could_open_propabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE = Module["__ZN7openmpt22could_open_propabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE"] = (a0, a1, a2) => (__ZN7openmpt22could_open_propabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE = Module["__ZN7openmpt22could_open_propabilityERNSt3__213basic_istreamIcNS0_11char_traitsIcEEEEdRNS0_13basic_ostreamIcS3_EE"] = wasmExports["Kc"])(a0, a1, a2);

var __ZN7openmpt38probe_file_header_get_recommended_sizeEv = Module["__ZN7openmpt38probe_file_header_get_recommended_sizeEv"] = () => (__ZN7openmpt38probe_file_header_get_recommended_sizeEv = Module["__ZN7openmpt38probe_file_header_get_recommended_sizeEv"] = wasmExports["Lc"])();

var __ZN7openmpt17probe_file_headerEyPKSt4bytemy = Module["__ZN7openmpt17probe_file_headerEyPKSt4bytemy"] = (a0, a1, a2, a3, a4, a5) => (__ZN7openmpt17probe_file_headerEyPKSt4bytemy = Module["__ZN7openmpt17probe_file_headerEyPKSt4bytemy"] = wasmExports["Mc"])(a0, a1, a2, a3, a4, a5);

var __ZN7openmpt17probe_file_headerEyPKhmy = Module["__ZN7openmpt17probe_file_headerEyPKhmy"] = (a0, a1, a2, a3, a4, a5) => (__ZN7openmpt17probe_file_headerEyPKhmy = Module["__ZN7openmpt17probe_file_headerEyPKhmy"] = wasmExports["Nc"])(a0, a1, a2, a3, a4, a5);

var __ZN7openmpt17probe_file_headerEyPKSt4bytem = Module["__ZN7openmpt17probe_file_headerEyPKSt4bytem"] = (a0, a1, a2, a3) => (__ZN7openmpt17probe_file_headerEyPKSt4bytem = Module["__ZN7openmpt17probe_file_headerEyPKSt4bytem"] = wasmExports["Oc"])(a0, a1, a2, a3);

var __ZN7openmpt17probe_file_headerEyPKhm = Module["__ZN7openmpt17probe_file_headerEyPKhm"] = (a0, a1, a2, a3) => (__ZN7openmpt17probe_file_headerEyPKhm = Module["__ZN7openmpt17probe_file_headerEyPKhm"] = wasmExports["Pc"])(a0, a1, a2, a3);

var __ZN7openmpt17probe_file_headerEyRNSt3__213basic_istreamIcNS0_11char_traitsIcEEEE = Module["__ZN7openmpt17probe_file_headerEyRNSt3__213basic_istreamIcNS0_11char_traitsIcEEEE"] = (a0, a1, a2) => (__ZN7openmpt17probe_file_headerEyRNSt3__213basic_istreamIcNS0_11char_traitsIcEEEE = Module["__ZN7openmpt17probe_file_headerEyRNSt3__213basic_istreamIcNS0_11char_traitsIcEEEE"] = wasmExports["Qc"])(a0, a1, a2);

var __ZN7openmpt6moduleC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = wasmExports["Rc"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt6moduleC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt6moduleC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = wasmExports["Sc"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC2EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC2EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC2EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = wasmExports["Tc"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = wasmExports["Uc"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt6moduleC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt6moduleC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = wasmExports["Vc"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC2EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Wc"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Xc"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt6moduleC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt6moduleC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = wasmExports["Yc"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC2EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Zc"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["_c"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["$c"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleD2Ev = Module["__ZN7openmpt6moduleD2Ev"] = a0 => (__ZN7openmpt6moduleD2Ev = Module["__ZN7openmpt6moduleD2Ev"] = wasmExports["ad"])(a0);

var __ZN7openmpt6moduleD0Ev = Module["__ZN7openmpt6moduleD0Ev"] = a0 => (__ZN7openmpt6moduleD0Ev = Module["__ZN7openmpt6moduleD0Ev"] = wasmExports["bd"])(a0);

var __ZN7openmpt6module14select_subsongEi = Module["__ZN7openmpt6module14select_subsongEi"] = (a0, a1) => (__ZN7openmpt6module14select_subsongEi = Module["__ZN7openmpt6module14select_subsongEi"] = wasmExports["cd"])(a0, a1);

var __ZNK7openmpt6module20get_selected_subsongEv = Module["__ZNK7openmpt6module20get_selected_subsongEv"] = a0 => (__ZNK7openmpt6module20get_selected_subsongEv = Module["__ZNK7openmpt6module20get_selected_subsongEv"] = wasmExports["dd"])(a0);

var __ZN7openmpt6module16set_repeat_countEi = Module["__ZN7openmpt6module16set_repeat_countEi"] = (a0, a1) => (__ZN7openmpt6module16set_repeat_countEi = Module["__ZN7openmpt6module16set_repeat_countEi"] = wasmExports["ed"])(a0, a1);

var __ZNK7openmpt6module16get_repeat_countEv = Module["__ZNK7openmpt6module16get_repeat_countEv"] = a0 => (__ZNK7openmpt6module16get_repeat_countEv = Module["__ZNK7openmpt6module16get_repeat_countEv"] = wasmExports["fd"])(a0);

var __ZNK7openmpt6module20get_duration_secondsEv = Module["__ZNK7openmpt6module20get_duration_secondsEv"] = a0 => (__ZNK7openmpt6module20get_duration_secondsEv = Module["__ZNK7openmpt6module20get_duration_secondsEv"] = wasmExports["gd"])(a0);

var __ZN7openmpt6module20set_position_secondsEd = Module["__ZN7openmpt6module20set_position_secondsEd"] = (a0, a1) => (__ZN7openmpt6module20set_position_secondsEd = Module["__ZN7openmpt6module20set_position_secondsEd"] = wasmExports["hd"])(a0, a1);

var __ZNK7openmpt6module20get_position_secondsEv = Module["__ZNK7openmpt6module20get_position_secondsEv"] = a0 => (__ZNK7openmpt6module20get_position_secondsEv = Module["__ZNK7openmpt6module20get_position_secondsEv"] = wasmExports["id"])(a0);

var __ZN7openmpt6module22set_position_order_rowEii = Module["__ZN7openmpt6module22set_position_order_rowEii"] = (a0, a1, a2) => (__ZN7openmpt6module22set_position_order_rowEii = Module["__ZN7openmpt6module22set_position_order_rowEii"] = wasmExports["jd"])(a0, a1, a2);

var __ZNK7openmpt6module16get_render_paramEi = Module["__ZNK7openmpt6module16get_render_paramEi"] = (a0, a1) => (__ZNK7openmpt6module16get_render_paramEi = Module["__ZNK7openmpt6module16get_render_paramEi"] = wasmExports["kd"])(a0, a1);

var __ZN7openmpt6module16set_render_paramEii = Module["__ZN7openmpt6module16set_render_paramEii"] = (a0, a1, a2) => (__ZN7openmpt6module16set_render_paramEii = Module["__ZN7openmpt6module16set_render_paramEii"] = wasmExports["ld"])(a0, a1, a2);

var __ZN7openmpt6module4readEimPs = Module["__ZN7openmpt6module4readEimPs"] = (a0, a1, a2, a3) => (__ZN7openmpt6module4readEimPs = Module["__ZN7openmpt6module4readEimPs"] = wasmExports["md"])(a0, a1, a2, a3);

var __ZN7openmpt6module4readEimPsS1_ = Module["__ZN7openmpt6module4readEimPsS1_"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6module4readEimPsS1_ = Module["__ZN7openmpt6module4readEimPsS1_"] = wasmExports["nd"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6module4readEimPsS1_S1_S1_ = Module["__ZN7openmpt6module4readEimPsS1_S1_S1_"] = (a0, a1, a2, a3, a4, a5, a6) => (__ZN7openmpt6module4readEimPsS1_S1_S1_ = Module["__ZN7openmpt6module4readEimPsS1_S1_S1_"] = wasmExports["od"])(a0, a1, a2, a3, a4, a5, a6);

var __ZN7openmpt6module4readEimPf = Module["__ZN7openmpt6module4readEimPf"] = (a0, a1, a2, a3) => (__ZN7openmpt6module4readEimPf = Module["__ZN7openmpt6module4readEimPf"] = wasmExports["pd"])(a0, a1, a2, a3);

var __ZN7openmpt6module4readEimPfS1_ = Module["__ZN7openmpt6module4readEimPfS1_"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6module4readEimPfS1_ = Module["__ZN7openmpt6module4readEimPfS1_"] = wasmExports["qd"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6module4readEimPfS1_S1_S1_ = Module["__ZN7openmpt6module4readEimPfS1_S1_S1_"] = (a0, a1, a2, a3, a4, a5, a6) => (__ZN7openmpt6module4readEimPfS1_S1_S1_ = Module["__ZN7openmpt6module4readEimPfS1_S1_S1_"] = wasmExports["rd"])(a0, a1, a2, a3, a4, a5, a6);

var __ZN7openmpt6module23read_interleaved_stereoEimPs = Module["__ZN7openmpt6module23read_interleaved_stereoEimPs"] = (a0, a1, a2, a3) => (__ZN7openmpt6module23read_interleaved_stereoEimPs = Module["__ZN7openmpt6module23read_interleaved_stereoEimPs"] = wasmExports["sd"])(a0, a1, a2, a3);

var __ZN7openmpt6module21read_interleaved_quadEimPs = Module["__ZN7openmpt6module21read_interleaved_quadEimPs"] = (a0, a1, a2, a3) => (__ZN7openmpt6module21read_interleaved_quadEimPs = Module["__ZN7openmpt6module21read_interleaved_quadEimPs"] = wasmExports["td"])(a0, a1, a2, a3);

var __ZN7openmpt6module23read_interleaved_stereoEimPf = Module["__ZN7openmpt6module23read_interleaved_stereoEimPf"] = (a0, a1, a2, a3) => (__ZN7openmpt6module23read_interleaved_stereoEimPf = Module["__ZN7openmpt6module23read_interleaved_stereoEimPf"] = wasmExports["ud"])(a0, a1, a2, a3);

var __ZN7openmpt6module21read_interleaved_quadEimPf = Module["__ZN7openmpt6module21read_interleaved_quadEimPf"] = (a0, a1, a2, a3) => (__ZN7openmpt6module21read_interleaved_quadEimPf = Module["__ZN7openmpt6module21read_interleaved_quadEimPf"] = wasmExports["vd"])(a0, a1, a2, a3);

var __ZNK7openmpt6module17get_metadata_keysEv = Module["__ZNK7openmpt6module17get_metadata_keysEv"] = (a0, a1) => (__ZNK7openmpt6module17get_metadata_keysEv = Module["__ZNK7openmpt6module17get_metadata_keysEv"] = wasmExports["wd"])(a0, a1);

var __ZNK7openmpt6module12get_metadataERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZNK7openmpt6module12get_metadataERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = (a0, a1, a2) => (__ZNK7openmpt6module12get_metadataERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZNK7openmpt6module12get_metadataERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = wasmExports["xd"])(a0, a1, a2);

var __ZNK7openmpt6module25get_current_estimated_bpmEv = Module["__ZNK7openmpt6module25get_current_estimated_bpmEv"] = a0 => (__ZNK7openmpt6module25get_current_estimated_bpmEv = Module["__ZNK7openmpt6module25get_current_estimated_bpmEv"] = wasmExports["yd"])(a0);

var __ZNK7openmpt6module17get_current_speedEv = Module["__ZNK7openmpt6module17get_current_speedEv"] = a0 => (__ZNK7openmpt6module17get_current_speedEv = Module["__ZNK7openmpt6module17get_current_speedEv"] = wasmExports["zd"])(a0);

var __ZNK7openmpt6module17get_current_tempoEv = Module["__ZNK7openmpt6module17get_current_tempoEv"] = a0 => (__ZNK7openmpt6module17get_current_tempoEv = Module["__ZNK7openmpt6module17get_current_tempoEv"] = wasmExports["Ad"])(a0);

var __ZNK7openmpt6module18get_current_tempo2Ev = Module["__ZNK7openmpt6module18get_current_tempo2Ev"] = a0 => (__ZNK7openmpt6module18get_current_tempo2Ev = Module["__ZNK7openmpt6module18get_current_tempo2Ev"] = wasmExports["Bd"])(a0);

var __ZNK7openmpt6module17get_current_orderEv = Module["__ZNK7openmpt6module17get_current_orderEv"] = a0 => (__ZNK7openmpt6module17get_current_orderEv = Module["__ZNK7openmpt6module17get_current_orderEv"] = wasmExports["Cd"])(a0);

var __ZNK7openmpt6module19get_current_patternEv = Module["__ZNK7openmpt6module19get_current_patternEv"] = a0 => (__ZNK7openmpt6module19get_current_patternEv = Module["__ZNK7openmpt6module19get_current_patternEv"] = wasmExports["Dd"])(a0);

var __ZNK7openmpt6module15get_current_rowEv = Module["__ZNK7openmpt6module15get_current_rowEv"] = a0 => (__ZNK7openmpt6module15get_current_rowEv = Module["__ZNK7openmpt6module15get_current_rowEv"] = wasmExports["Ed"])(a0);

var __ZNK7openmpt6module28get_current_playing_channelsEv = Module["__ZNK7openmpt6module28get_current_playing_channelsEv"] = a0 => (__ZNK7openmpt6module28get_current_playing_channelsEv = Module["__ZNK7openmpt6module28get_current_playing_channelsEv"] = wasmExports["Fd"])(a0);

var __ZNK7openmpt6module27get_current_channel_vu_monoEi = Module["__ZNK7openmpt6module27get_current_channel_vu_monoEi"] = (a0, a1) => (__ZNK7openmpt6module27get_current_channel_vu_monoEi = Module["__ZNK7openmpt6module27get_current_channel_vu_monoEi"] = wasmExports["Gd"])(a0, a1);

var __ZNK7openmpt6module27get_current_channel_vu_leftEi = Module["__ZNK7openmpt6module27get_current_channel_vu_leftEi"] = (a0, a1) => (__ZNK7openmpt6module27get_current_channel_vu_leftEi = Module["__ZNK7openmpt6module27get_current_channel_vu_leftEi"] = wasmExports["Hd"])(a0, a1);

var __ZNK7openmpt6module28get_current_channel_vu_rightEi = Module["__ZNK7openmpt6module28get_current_channel_vu_rightEi"] = (a0, a1) => (__ZNK7openmpt6module28get_current_channel_vu_rightEi = Module["__ZNK7openmpt6module28get_current_channel_vu_rightEi"] = wasmExports["Id"])(a0, a1);

var __ZNK7openmpt6module32get_current_channel_vu_rear_leftEi = Module["__ZNK7openmpt6module32get_current_channel_vu_rear_leftEi"] = (a0, a1) => (__ZNK7openmpt6module32get_current_channel_vu_rear_leftEi = Module["__ZNK7openmpt6module32get_current_channel_vu_rear_leftEi"] = wasmExports["Jd"])(a0, a1);

var __ZNK7openmpt6module33get_current_channel_vu_rear_rightEi = Module["__ZNK7openmpt6module33get_current_channel_vu_rear_rightEi"] = (a0, a1) => (__ZNK7openmpt6module33get_current_channel_vu_rear_rightEi = Module["__ZNK7openmpt6module33get_current_channel_vu_rear_rightEi"] = wasmExports["Kd"])(a0, a1);

var __ZNK7openmpt6module16get_num_subsongsEv = Module["__ZNK7openmpt6module16get_num_subsongsEv"] = a0 => (__ZNK7openmpt6module16get_num_subsongsEv = Module["__ZNK7openmpt6module16get_num_subsongsEv"] = wasmExports["Ld"])(a0);

var __ZNK7openmpt6module16get_num_channelsEv = Module["__ZNK7openmpt6module16get_num_channelsEv"] = a0 => (__ZNK7openmpt6module16get_num_channelsEv = Module["__ZNK7openmpt6module16get_num_channelsEv"] = wasmExports["Md"])(a0);

var __ZNK7openmpt6module14get_num_ordersEv = Module["__ZNK7openmpt6module14get_num_ordersEv"] = a0 => (__ZNK7openmpt6module14get_num_ordersEv = Module["__ZNK7openmpt6module14get_num_ordersEv"] = wasmExports["Nd"])(a0);

var __ZNK7openmpt6module16get_num_patternsEv = Module["__ZNK7openmpt6module16get_num_patternsEv"] = a0 => (__ZNK7openmpt6module16get_num_patternsEv = Module["__ZNK7openmpt6module16get_num_patternsEv"] = wasmExports["Od"])(a0);

var __ZNK7openmpt6module19get_num_instrumentsEv = Module["__ZNK7openmpt6module19get_num_instrumentsEv"] = a0 => (__ZNK7openmpt6module19get_num_instrumentsEv = Module["__ZNK7openmpt6module19get_num_instrumentsEv"] = wasmExports["Pd"])(a0);

var __ZNK7openmpt6module15get_num_samplesEv = Module["__ZNK7openmpt6module15get_num_samplesEv"] = a0 => (__ZNK7openmpt6module15get_num_samplesEv = Module["__ZNK7openmpt6module15get_num_samplesEv"] = wasmExports["Qd"])(a0);

var __ZNK7openmpt6module17get_subsong_namesEv = Module["__ZNK7openmpt6module17get_subsong_namesEv"] = (a0, a1) => (__ZNK7openmpt6module17get_subsong_namesEv = Module["__ZNK7openmpt6module17get_subsong_namesEv"] = wasmExports["Rd"])(a0, a1);

var __ZNK7openmpt6module17get_channel_namesEv = Module["__ZNK7openmpt6module17get_channel_namesEv"] = (a0, a1) => (__ZNK7openmpt6module17get_channel_namesEv = Module["__ZNK7openmpt6module17get_channel_namesEv"] = wasmExports["Sd"])(a0, a1);

var __ZNK7openmpt6module15get_order_namesEv = Module["__ZNK7openmpt6module15get_order_namesEv"] = (a0, a1) => (__ZNK7openmpt6module15get_order_namesEv = Module["__ZNK7openmpt6module15get_order_namesEv"] = wasmExports["Td"])(a0, a1);

var __ZNK7openmpt6module17get_pattern_namesEv = Module["__ZNK7openmpt6module17get_pattern_namesEv"] = (a0, a1) => (__ZNK7openmpt6module17get_pattern_namesEv = Module["__ZNK7openmpt6module17get_pattern_namesEv"] = wasmExports["Ud"])(a0, a1);

var __ZNK7openmpt6module20get_instrument_namesEv = Module["__ZNK7openmpt6module20get_instrument_namesEv"] = (a0, a1) => (__ZNK7openmpt6module20get_instrument_namesEv = Module["__ZNK7openmpt6module20get_instrument_namesEv"] = wasmExports["Vd"])(a0, a1);

var __ZNK7openmpt6module16get_sample_namesEv = Module["__ZNK7openmpt6module16get_sample_namesEv"] = (a0, a1) => (__ZNK7openmpt6module16get_sample_namesEv = Module["__ZNK7openmpt6module16get_sample_namesEv"] = wasmExports["Wd"])(a0, a1);

var __ZNK7openmpt6module17get_order_patternEi = Module["__ZNK7openmpt6module17get_order_patternEi"] = (a0, a1) => (__ZNK7openmpt6module17get_order_patternEi = Module["__ZNK7openmpt6module17get_order_patternEi"] = wasmExports["Xd"])(a0, a1);

var __ZNK7openmpt6module20get_pattern_num_rowsEi = Module["__ZNK7openmpt6module20get_pattern_num_rowsEi"] = (a0, a1) => (__ZNK7openmpt6module20get_pattern_num_rowsEi = Module["__ZNK7openmpt6module20get_pattern_num_rowsEi"] = wasmExports["Yd"])(a0, a1);

var __ZNK7openmpt6module31get_pattern_row_channel_commandEiiii = Module["__ZNK7openmpt6module31get_pattern_row_channel_commandEiiii"] = (a0, a1, a2, a3, a4) => (__ZNK7openmpt6module31get_pattern_row_channel_commandEiiii = Module["__ZNK7openmpt6module31get_pattern_row_channel_commandEiiii"] = wasmExports["Zd"])(a0, a1, a2, a3, a4);

var __ZNK7openmpt6module34format_pattern_row_channel_commandEiiii = Module["__ZNK7openmpt6module34format_pattern_row_channel_commandEiiii"] = (a0, a1, a2, a3, a4, a5) => (__ZNK7openmpt6module34format_pattern_row_channel_commandEiiii = Module["__ZNK7openmpt6module34format_pattern_row_channel_commandEiiii"] = wasmExports["_d"])(a0, a1, a2, a3, a4, a5);

var __ZNK7openmpt6module37highlight_pattern_row_channel_commandEiiii = Module["__ZNK7openmpt6module37highlight_pattern_row_channel_commandEiiii"] = (a0, a1, a2, a3, a4, a5) => (__ZNK7openmpt6module37highlight_pattern_row_channel_commandEiiii = Module["__ZNK7openmpt6module37highlight_pattern_row_channel_commandEiiii"] = wasmExports["$d"])(a0, a1, a2, a3, a4, a5);

var __ZNK7openmpt6module26format_pattern_row_channelEiiimb = Module["__ZNK7openmpt6module26format_pattern_row_channelEiiimb"] = (a0, a1, a2, a3, a4, a5, a6) => (__ZNK7openmpt6module26format_pattern_row_channelEiiimb = Module["__ZNK7openmpt6module26format_pattern_row_channelEiiimb"] = wasmExports["ae"])(a0, a1, a2, a3, a4, a5, a6);

var __ZNK7openmpt6module29highlight_pattern_row_channelEiiimb = Module["__ZNK7openmpt6module29highlight_pattern_row_channelEiiimb"] = (a0, a1, a2, a3, a4, a5, a6) => (__ZNK7openmpt6module29highlight_pattern_row_channelEiiimb = Module["__ZNK7openmpt6module29highlight_pattern_row_channelEiiimb"] = wasmExports["be"])(a0, a1, a2, a3, a4, a5, a6);

var __ZNK7openmpt6module8get_ctlsEv = Module["__ZNK7openmpt6module8get_ctlsEv"] = (a0, a1) => (__ZNK7openmpt6module8get_ctlsEv = Module["__ZNK7openmpt6module8get_ctlsEv"] = wasmExports["ce"])(a0, a1);

var __ZNK7openmpt6module7ctl_getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZNK7openmpt6module7ctl_getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = (a0, a1, a2) => (__ZNK7openmpt6module7ctl_getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZNK7openmpt6module7ctl_getERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = wasmExports["de"])(a0, a1, a2);

var __ZNK7openmpt6module15ctl_get_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module15ctl_get_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = (a0, a1) => (__ZNK7openmpt6module15ctl_get_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module15ctl_get_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = wasmExports["ee"])(a0, a1);

var __ZNK7openmpt6module15ctl_get_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module15ctl_get_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = (a0, a1) => (__ZNK7openmpt6module15ctl_get_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module15ctl_get_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = wasmExports["fe"])(a0, a1);

var __ZNK7openmpt6module21ctl_get_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module21ctl_get_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = (a0, a1) => (__ZNK7openmpt6module21ctl_get_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module21ctl_get_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = wasmExports["ge"])(a0, a1);

var __ZNK7openmpt6module12ctl_get_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module12ctl_get_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = (a0, a1, a2) => (__ZNK7openmpt6module12ctl_get_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE = Module["__ZNK7openmpt6module12ctl_get_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEE"] = wasmExports["he"])(a0, a1, a2);

var __ZN7openmpt6module7ctl_setERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_ = Module["__ZN7openmpt6module7ctl_setERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_"] = (a0, a1, a2) => (__ZN7openmpt6module7ctl_setERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_ = Module["__ZN7openmpt6module7ctl_setERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEES9_"] = wasmExports["ie"])(a0, a1, a2);

var __ZN7openmpt6module15ctl_set_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEb = Module["__ZN7openmpt6module15ctl_set_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEb"] = (a0, a1, a2) => (__ZN7openmpt6module15ctl_set_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEb = Module["__ZN7openmpt6module15ctl_set_booleanENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEb"] = wasmExports["je"])(a0, a1, a2);

var __ZN7openmpt6module15ctl_set_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEx = Module["__ZN7openmpt6module15ctl_set_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEx"] = (a0, a1, a2, a3) => (__ZN7openmpt6module15ctl_set_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEx = Module["__ZN7openmpt6module15ctl_set_integerENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEx"] = wasmExports["ke"])(a0, a1, a2, a3);

var __ZN7openmpt6module21ctl_set_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEd = Module["__ZN7openmpt6module21ctl_set_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEd"] = (a0, a1, a2) => (__ZN7openmpt6module21ctl_set_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEd = Module["__ZN7openmpt6module21ctl_set_floatingpointENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEEd"] = wasmExports["le"])(a0, a1, a2);

var __ZN7openmpt6module12ctl_set_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEES5_ = Module["__ZN7openmpt6module12ctl_set_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEES5_"] = (a0, a1, a2) => (__ZN7openmpt6module12ctl_set_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEES5_ = Module["__ZN7openmpt6module12ctl_set_textENSt3__217basic_string_viewIcNS1_11char_traitsIcEEEES5_"] = wasmExports["me"])(a0, a1, a2);

var __ZN7openmpt10module_extC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC2ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = wasmExports["ne"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt10module_extC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt10module_extC2ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = wasmExports["oe"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt10module_extC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt10module_extC2ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = wasmExports["pe"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt10module_extC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt10module_extC2ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = wasmExports["qe"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC2EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["re"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC2EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["se"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC2EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = wasmExports["te"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC2EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["ue"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extD2Ev = Module["__ZN7openmpt10module_extD2Ev"] = a0 => (__ZN7openmpt10module_extD2Ev = Module["__ZN7openmpt10module_extD2Ev"] = wasmExports["ve"])(a0);

var __ZN7openmpt10module_extD0Ev = Module["__ZN7openmpt10module_extD0Ev"] = a0 => (__ZN7openmpt10module_extD0Ev = Module["__ZN7openmpt10module_extD0Ev"] = wasmExports["we"])(a0);

var __ZN7openmpt10module_extC2ERKS0_ = Module["__ZN7openmpt10module_extC2ERKS0_"] = (a0, a1) => (__ZN7openmpt10module_extC2ERKS0_ = Module["__ZN7openmpt10module_extC2ERKS0_"] = wasmExports["xe"])(a0, a1);

var __ZN7openmpt10module_extaSERKS0_ = Module["__ZN7openmpt10module_extaSERKS0_"] = (a0, a1) => (__ZN7openmpt10module_extaSERKS0_ = Module["__ZN7openmpt10module_extaSERKS0_"] = wasmExports["ye"])(a0, a1);

var __ZN7openmpt10module_ext13get_interfaceERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt10module_ext13get_interfaceERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = (a0, a1) => (__ZN7openmpt10module_ext13get_interfaceERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt10module_ext13get_interfaceERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = wasmExports["ze"])(a0, a1);

var __ZN7openmpt9exceptionC1ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt9exceptionC1ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = (a0, a1) => (__ZN7openmpt9exceptionC1ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE = Module["__ZN7openmpt9exceptionC1ERKNSt3__212basic_stringIcNS1_11char_traitsIcEENS1_9allocatorIcEEEE"] = wasmExports["Ae"])(a0, a1);

var __ZN7openmpt9exceptionC1ERKS0_ = Module["__ZN7openmpt9exceptionC1ERKS0_"] = (a0, a1) => (__ZN7openmpt9exceptionC1ERKS0_ = Module["__ZN7openmpt9exceptionC1ERKS0_"] = wasmExports["Be"])(a0, a1);

var __ZN7openmpt9exceptionC1EOS0_ = Module["__ZN7openmpt9exceptionC1EOS0_"] = (a0, a1) => (__ZN7openmpt9exceptionC1EOS0_ = Module["__ZN7openmpt9exceptionC1EOS0_"] = wasmExports["Ce"])(a0, a1);

var __ZN7openmpt9exceptionD1Ev = Module["__ZN7openmpt9exceptionD1Ev"] = a0 => (__ZN7openmpt9exceptionD1Ev = Module["__ZN7openmpt9exceptionD1Ev"] = wasmExports["De"])(a0);

var __ZN7openmpt6moduleC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = wasmExports["Ee"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt6moduleC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt6moduleC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = wasmExports["Fe"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC1EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC1EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC1EPKSt4byteS3_RNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = wasmExports["Ge"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt6moduleC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = wasmExports["He"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt6moduleC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt6moduleC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = wasmExports["Ie"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC1EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKhS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Je"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Ke"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt6moduleC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt6moduleC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt6moduleC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = wasmExports["Le"])(a0, a1, a2, a3);

var __ZN7openmpt6moduleC1EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKcS2_RNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Me"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Ne"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt6moduleC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt6moduleC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Oe"])(a0, a1, a2, a3, a4);

var __ZN7openmpt6moduleD1Ev = Module["__ZN7openmpt6moduleD1Ev"] = a0 => (__ZN7openmpt6moduleD1Ev = Module["__ZN7openmpt6moduleD1Ev"] = wasmExports["Pe"])(a0);

var __ZN7openmpt10module_extC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC1ERNSt3__213basic_istreamIcNS1_11char_traitsIcEEEERNS1_13basic_ostreamIcS4_EERKNS1_3mapINS1_12basic_stringIcS4_NS1_9allocatorIcEEEESE_NS1_4lessISE_EENSC_INS1_4pairIKSE_SE_EEEEEE"] = wasmExports["Qe"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt10module_extC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE = Module["__ZN7openmpt10module_extC1ERKNSt3__26vectorIhNS1_9allocatorIhEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_NS3_IcEEEESG_NS1_4lessISG_EENS3_INS1_4pairIKSG_SG_EEEEEE"] = wasmExports["Re"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt10module_extC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE = Module["__ZN7openmpt10module_extC1ERKNSt3__26vectorIcNS1_9allocatorIcEEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSA_S4_EESF_NS1_4lessISF_EENS3_INS1_4pairIKSF_SF_EEEEEE"] = wasmExports["Se"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt10module_extC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = (a0, a1, a2, a3) => (__ZN7openmpt10module_extC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE = Module["__ZN7openmpt10module_extC1ERKNSt3__26vectorISt4byteNS1_9allocatorIS3_EEEERNS1_13basic_ostreamIcNS1_11char_traitsIcEEEERKNS1_3mapINS1_12basic_stringIcSB_NS4_IcEEEESH_NS1_4lessISH_EENS4_INS1_4pairIKSH_SH_EEEEEE"] = wasmExports["Te"])(a0, a1, a2, a3);

var __ZN7openmpt10module_extC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC1EPKhmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Ue"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC1EPKcmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Ve"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE = Module["__ZN7openmpt10module_extC1EPKSt4bytemRNSt3__213basic_ostreamIcNS4_11char_traitsIcEEEERKNS4_3mapINS4_12basic_stringIcS7_NS4_9allocatorIcEEEESE_NS4_4lessISE_EENSC_INS4_4pairIKSE_SE_EEEEEE"] = wasmExports["We"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = (a0, a1, a2, a3, a4) => (__ZN7openmpt10module_extC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE = Module["__ZN7openmpt10module_extC1EPKvmRNSt3__213basic_ostreamIcNS3_11char_traitsIcEEEERKNS3_3mapINS3_12basic_stringIcS6_NS3_9allocatorIcEEEESD_NS3_4lessISD_EENSB_INS3_4pairIKSD_SD_EEEEEE"] = wasmExports["Xe"])(a0, a1, a2, a3, a4);

var __ZN7openmpt10module_extD1Ev = Module["__ZN7openmpt10module_extD1Ev"] = a0 => (__ZN7openmpt10module_extD1Ev = Module["__ZN7openmpt10module_extD1Ev"] = wasmExports["Ye"])(a0);

var __ZN7openmpt10module_extC1ERKS0_ = Module["__ZN7openmpt10module_extC1ERKS0_"] = (a0, a1) => (__ZN7openmpt10module_extC1ERKS0_ = Module["__ZN7openmpt10module_extC1ERKS0_"] = wasmExports["Ze"])(a0, a1);

var _setThrew = (a0, a1) => (_setThrew = wasmExports["$e"])(a0, a1);

var __emscripten_tempret_set = a0 => (__emscripten_tempret_set = wasmExports["af"])(a0);

var __emscripten_stack_restore = a0 => (__emscripten_stack_restore = wasmExports["bf"])(a0);

var _emscripten_stack_get_current = () => (_emscripten_stack_get_current = wasmExports["cf"])();

var ___cxa_decrement_exception_refcount = a0 => (___cxa_decrement_exception_refcount = wasmExports["df"])(a0);

var ___cxa_increment_exception_refcount = a0 => (___cxa_increment_exception_refcount = wasmExports["ef"])(a0);

var ___cxa_can_catch = (a0, a1, a2) => (___cxa_can_catch = wasmExports["ff"])(a0, a1, a2);

var ___cxa_is_pointer_type = a0 => (___cxa_is_pointer_type = wasmExports["gf"])(a0);

var dynCall_j = Module["dynCall_j"] = a0 => (dynCall_j = Module["dynCall_j"] = wasmExports["hf"])(a0);

var dynCall_viiji = Module["dynCall_viiji"] = (a0, a1, a2, a3, a4, a5) => (dynCall_viiji = Module["dynCall_viiji"] = wasmExports["jf"])(a0, a1, a2, a3, a4, a5);

var dynCall_iiji = Module["dynCall_iiji"] = (a0, a1, a2, a3, a4) => (dynCall_iiji = Module["dynCall_iiji"] = wasmExports["kf"])(a0, a1, a2, a3, a4);

var dynCall_vij = Module["dynCall_vij"] = (a0, a1, a2, a3) => (dynCall_vij = Module["dynCall_vij"] = wasmExports["lf"])(a0, a1, a2, a3);

var dynCall_viij = Module["dynCall_viij"] = (a0, a1, a2, a3, a4) => (dynCall_viij = Module["dynCall_viij"] = wasmExports["mf"])(a0, a1, a2, a3, a4);

var dynCall_viiij = Module["dynCall_viiij"] = (a0, a1, a2, a3, a4, a5) => (dynCall_viiij = Module["dynCall_viiij"] = wasmExports["nf"])(a0, a1, a2, a3, a4, a5);

var dynCall_ijiij = Module["dynCall_ijiij"] = (a0, a1, a2, a3, a4, a5, a6) => (dynCall_ijiij = Module["dynCall_ijiij"] = wasmExports["of"])(a0, a1, a2, a3, a4, a5, a6);

var dynCall_viji = Module["dynCall_viji"] = (a0, a1, a2, a3, a4) => (dynCall_viji = Module["dynCall_viji"] = wasmExports["pf"])(a0, a1, a2, a3, a4);

var dynCall_jiiii = Module["dynCall_jiiii"] = (a0, a1, a2, a3, a4) => (dynCall_jiiii = Module["dynCall_jiiii"] = wasmExports["qf"])(a0, a1, a2, a3, a4);

var dynCall_iij = Module["dynCall_iij"] = (a0, a1, a2, a3) => (dynCall_iij = Module["dynCall_iij"] = wasmExports["rf"])(a0, a1, a2, a3);

function invoke_iii(index, a1, a2) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viii(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_vii(index, a1, a2) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_ii(index, a1) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiii(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiiiii(index, a1, a2, a3, a4, a5, a6) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_vi(index, a1) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_v(index) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)();
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiii(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7, a8);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiii(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7, a8);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_i(index) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)();
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiiii(index, a1, a2, a3, a4, a5, a6) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiii(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiiiii(index, a1, a2, a3, a4, a5, a6, a7) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8, a9) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7, a8, a9);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_di(index, a1) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_fi(index, a1) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiiii(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viif(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_vid(index, a1, a2) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiifii(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_fii(index, a1, a2) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_didi(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_diiii(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiidi(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iifi(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiiiiii(index, a1, a2, a3, a4, a5, a6, a7) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_diii(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_did(index, a1, a2) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viid(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_dii(index, a1, a2) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiidd(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iid(index, a1, a2) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiiid(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiiiiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11) {
  var sp = stackSave();
  try {
    return getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7, a8, a9, a10);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiiiiiiiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12, a13, a14, a15) {
  var sp = stackSave();
  try {
    getWasmTableEntry(index)(a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12, a13, a14, a15);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iiji(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    return dynCall_iiji(index, a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_vij(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    dynCall_vij(index, a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiij(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    dynCall_viiij(index, a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viij(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    dynCall_viij(index, a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_jiiii(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    return dynCall_jiiii(index, a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viiji(index, a1, a2, a3, a4, a5) {
  var sp = stackSave();
  try {
    dynCall_viiji(index, a1, a2, a3, a4, a5);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_ijiij(index, a1, a2, a3, a4, a5, a6) {
  var sp = stackSave();
  try {
    return dynCall_ijiij(index, a1, a2, a3, a4, a5, a6);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_viji(index, a1, a2, a3, a4) {
  var sp = stackSave();
  try {
    dynCall_viji(index, a1, a2, a3, a4);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_j(index) {
  var sp = stackSave();
  try {
    return dynCall_j(index);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

function invoke_iij(index, a1, a2, a3) {
  var sp = stackSave();
  try {
    return dynCall_iij(index, a1, a2, a3);
  } catch (e) {
    stackRestore(sp);
    if (e !== e + 0) throw e;
    _setThrew(1, 0);
  }
}

var calledRun;

dependenciesFulfilled = function runCaller() {
  if (!calledRun) run();
  if (!calledRun) dependenciesFulfilled = runCaller;
};

function run() {
  if (runDependencies > 0) {
    return;
  }
  preRun();
  if (runDependencies > 0) {
    return;
  }
  function doRun() {
    if (calledRun) return;
    calledRun = true;
    Module["calledRun"] = true;
    if (ABORT) return;
    initRuntime();
    if (Module["onRuntimeInitialized"]) Module["onRuntimeInitialized"]();
    postRun();
  }
  if (Module["setStatus"]) {
    Module["setStatus"]("Running...");
    setTimeout(function() {
      setTimeout(function() {
        Module["setStatus"]("");
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}

if (Module["preInit"]) {
  if (typeof Module["preInit"] == "function") Module["preInit"] = [ Module["preInit"] ];
  while (Module["preInit"].length > 0) {
    Module["preInit"].pop()();
  }
}

run();
